---
stage: Plan
group: Project Management
info: To determine the technical writer assigned to the Stage/Group associated with this page, see https://about.gitlab.com/handbook/engineering/ux/technical-writing/#designated-technical-writers
---

<!---
  This documentation is auto generated by a script.

  Please do not edit this file directly, check compile_docs task on lib/tasks/gitlab/graphql.rake.
--->

# GraphQL API Resources

This documentation is self-generated based on GitLab current GraphQL schema.

The API can be explored interactively using the [GraphiQL IDE](../index.md#graphiql).

Each table below documents a GraphQL type. Types match loosely to models, but not all
fields and methods on a model are available via GraphQL.

WARNING:
Fields that are deprecated are marked with **{warning-solid}**.
Items (fields, enums, etc) that have been removed according to our [deprecation process](../index.md#deprecation-process) can be found
in [Removed Items](../removed_items.md).

## Object types

Object types represent the resources that the GitLab GraphQL API can return.
They contain _fields_. Each field has its own type, which will either be one of the
basic GraphQL [scalar types](https://graphql.org/learn/schema/#scalar-types)
(e.g.: `String` or `Boolean`) or other object types.

For more information, see
[Object Types and Fields](https://graphql.org/learn/schema/#object-types-and-fields)
on `graphql.org`.

### AccessLevel

Represents the access level of a relationship between a User and object that it is related to.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `integerValue` | Int | Integer representation of access level |
| `stringValue` | AccessLevelEnum | String representation of access level |

### AddAwardEmojiPayload

Autogenerated return type of AddAwardEmoji.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `awardEmoji` | AwardEmoji | The award emoji after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### AddProjectToSecurityDashboardPayload

Autogenerated return type of AddProjectToSecurityDashboard.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `project` | Project | Project that was added to the Instance Security Dashboard |

### AdminSidekiqQueuesDeleteJobsPayload

Autogenerated return type of AdminSidekiqQueuesDeleteJobs.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `result` | DeleteJobsResponse | Information about the status of the deletion request. |

### AlertManagementAlert

Describes an alert from the project's Alert Management.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `assignees` | UserConnection | Assignees of the alert |
| `createdAt` | Time | Timestamp the alert was created |
| `description` | String | Description of the alert |
| `details` | JSON | Alert details |
| `detailsUrl` | String! | The URL of the alert detail page |
| `discussions` | DiscussionConnection! | All discussions on this noteable |
| `endedAt` | Time | Timestamp the alert ended |
| `environment` | Environment | Environment for the alert |
| `eventCount` | Int | Number of events of this alert |
| `hosts` | String! => Array | List of hosts the alert came from |
| `iid` | ID! | Internal ID of the alert |
| `issueIid` | ID | Internal ID of the GitLab issue attached to the alert |
| `metricsDashboardUrl` | String | URL for metrics embed for the alert |
| `monitoringTool` | String | Monitoring tool the alert came from |
| `notes` | NoteConnection! | All notes on this noteable |
| `prometheusAlert` | PrometheusAlert | The alert condition for Prometheus |
| `runbook` | String | Runbook for the alert as defined in alert details |
| `service` | String | Service the alert came from |
| `severity` | AlertManagementSeverity | Severity of the alert |
| `startedAt` | Time | Timestamp the alert was raised |
| `status` | AlertManagementStatus | Status of the alert |
| `title` | String | Title of the alert |
| `todos` | TodoConnection | Todos of the current user for the alert |
| `updatedAt` | Time | Timestamp the alert was last updated |

### AlertManagementAlertStatusCountsType

Represents total number of alerts for the represented categories.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `acknowledged` | Int | Number of alerts with status ACKNOWLEDGED for the project |
| `all` | Int | Total number of alerts for the project |
| `ignored` | Int | Number of alerts with status IGNORED for the project |
| `open` | Int | Number of alerts with status TRIGGERED or ACKNOWLEDGED for the project |
| `resolved` | Int | Number of alerts with status RESOLVED for the project |
| `triggered` | Int | Number of alerts with status TRIGGERED for the project |

### AlertManagementHttpIntegration

An endpoint and credentials used to accept alerts for a project.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `active` | Boolean | Whether the endpoint is currently accepting alerts |
| `apiUrl` | String | URL at which Prometheus metrics can be queried to populate the metrics dashboard |
| `id` | ID! | ID of the integration |
| `name` | String | Name of the integration |
| `token` | String | Token used to authenticate alert notification requests |
| `type` | AlertManagementIntegrationType! | Type of integration |
| `url` | String | Endpoint which accepts alert notifications |

### AlertManagementPrometheusIntegration

An endpoint and credentials used to accept Prometheus alerts for a project.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `active` | Boolean | Whether the endpoint is currently accepting alerts |
| `apiUrl` | String | URL at which Prometheus metrics can be queried to populate the metrics dashboard |
| `id` | ID! | ID of the integration |
| `name` | String | Name of the integration |
| `token` | String | Token used to authenticate alert notification requests |
| `type` | AlertManagementIntegrationType! | Type of integration |
| `url` | String | Endpoint which accepts alert notifications |

### AlertSetAssigneesPayload

Autogenerated return type of AlertSetAssignees.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `alert` | AlertManagementAlert | The alert after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue created after mutation. |
| `todo` | Todo | The todo after mutation. |

### AlertTodoCreatePayload

Autogenerated return type of AlertTodoCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `alert` | AlertManagementAlert | The alert after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue created after mutation. |
| `todo` | Todo | The todo after mutation. |

### AwardEmoji

An emoji awarded by a user.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | String! | The emoji description |
| `emoji` | String! | The emoji as an icon |
| `name` | String! | The emoji name |
| `unicode` | String! | The emoji in unicode |
| `unicodeVersion` | String! | The unicode version for this emoji |
| `user` | User! | The user who awarded the emoji |

### AwardEmojiAddPayload

Autogenerated return type of AwardEmojiAdd.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `awardEmoji` | AwardEmoji | The award emoji after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### AwardEmojiRemovePayload

Autogenerated return type of AwardEmojiRemove.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `awardEmoji` | AwardEmoji | The award emoji after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### AwardEmojiTogglePayload

Autogenerated return type of AwardEmojiToggle.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `awardEmoji` | AwardEmoji | The award emoji after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `toggledOn` | Boolean! | Indicates the status of the emoji. True if the toggle awarded the emoji, and false if the toggle removed the emoji. |

### BaseService

| Field | Type | Description |
| ----- | ---- | ----------- |
| `active` | Boolean | Indicates if the service is active |
| `type` | String | Class name of the service |

### Blob

| Field | Type | Description |
| ----- | ---- | ----------- |
| `flatPath` | String! | Flat path of the entry |
| `id` | ID! | ID of the entry |
| `lfsOid` | String | LFS ID of the blob |
| `mode` | String | Blob mode in numeric format |
| `name` | String! | Name of the entry |
| `path` | String! | Path of the entry |
| `sha` | String! | Last commit sha for the entry |
| `type` | EntryType! | Type of tree entry |
| `webPath` | String | Web path of the blob |
| `webUrl` | String | Web URL of the blob |

### Board

Represents a project or group board.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `assignee` | User | The board assignee |
| `epics` | BoardEpicConnection | Epics associated with board issues |
| `hideBacklogList` | Boolean | Whether or not backlog list is hidden |
| `hideClosedList` | Boolean | Whether or not closed list is hidden |
| `id` | ID! | ID (global ID) of the board |
| `iteration` | Iteration | The board iteration. |
| `labels` | LabelConnection | Labels of the board |
| `lists` | BoardListConnection | Lists of the board |
| `milestone` | Milestone | The board milestone |
| `name` | String | Name of the board |
| `webPath` | String! | Web path of the board. |
| `webUrl` | String! | Web URL of the board. |
| `weight` | Int | Weight of the board |

### BoardEpic

Represents an epic on an issue board.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | User! | Author of the epic |
| `children` | EpicConnection | Children (sub-epics) of the epic |
| `closedAt` | Time | Timestamp of when the epic was closed |
| `confidential` | Boolean | Indicates if the epic is confidential |
| `createdAt` | Time | Timestamp of when the epic was created |
| `currentUserTodos` | TodoConnection! | Todos for the current user |
| `descendantCounts` | EpicDescendantCount | Number of open and closed descendant epics and issues |
| `descendantWeightSum` | EpicDescendantWeights | Total weight of open and closed issues in the epic and its descendants |
| `description` | String | Description of the epic |
| `discussions` | DiscussionConnection! | All discussions on this noteable |
| `downvotes` | Int! | Number of downvotes the epic has received |
| `dueDate` | Time | Due date of the epic |
| `dueDateFixed` | Time | Fixed due date of the epic |
| `dueDateFromMilestones` | Time | Inherited due date of the epic from milestones |
| `dueDateIsFixed` | Boolean | Indicates if the due date has been manually set |
| `group` | Group! | Group to which the epic belongs |
| `hasChildren` | Boolean! | Indicates if the epic has children |
| `hasIssues` | Boolean! | Indicates if the epic has direct issues |
| `hasParent` | Boolean! | Indicates if the epic has a parent epic |
| `healthStatus` | EpicHealthStatus | Current health status of the epic |
| `id` | ID! | ID of the epic |
| `iid` | ID! | Internal ID of the epic |
| `issues` | EpicIssueConnection | A list of issues associated with the epic |
| `labels` | LabelConnection | Labels assigned to the epic |
| `notes` | NoteConnection! | All notes on this noteable |
| `parent` | Epic | Parent epic of the epic |
| `participants` | UserConnection | List of participants for the epic |
| `reference` | String! | Internal reference of the epic. Returned in shortened format by default |
| `relationPath` | String | URI path of the epic-issue relationship |
| `relativePosition` | Int | The relative position of the epic in the epic tree |
| `startDate` | Time | Start date of the epic |
| `startDateFixed` | Time | Fixed start date of the epic |
| `startDateFromMilestones` | Time | Inherited start date of the epic from milestones |
| `startDateIsFixed` | Boolean | Indicates if the start date has been manually set |
| `state` | EpicState! | State of the epic |
| `subscribed` | Boolean! | Indicates the currently logged in user is subscribed to the epic |
| `title` | String | Title of the epic |
| `updatedAt` | Time | Timestamp of when the epic was updated |
| `upvotes` | Int! | Number of upvotes the epic has received |
| `userDiscussionsCount` | Int! | Number of user discussions in the epic |
| `userNotesCount` | Int! | Number of user notes of the epic |
| `userPermissions` | EpicPermissions! | Permissions for the current user on the resource |
| `userPreferences` | BoardEpicUserPreferences | User preferences for the epic on the issue board |
| `webPath` | String! | Web path of the epic |
| `webUrl` | String! | Web URL of the epic |

### BoardEpicUserPreferences

Represents user preferences for a board epic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `collapsed` | Boolean! | Indicates epic should be displayed as collapsed |

### BoardList

Represents a list for an issue board.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `assignee` | User | Assignee in the list |
| `collapsed` | Boolean | Indicates if list is collapsed for this user |
| `id` | ID! | ID (global ID) of the list |
| `issues` | IssueConnection | Board issues |
| `issuesCount` | Int | Count of issues in the list |
| `iteration` | Iteration | Iteration of the list |
| `label` | Label | Label of the list |
| `limitMetric` | ListLimitMetric | The current limit metric for the list |
| `listType` | String! | Type of the list |
| `maxIssueCount` | Int | Maximum number of issues in the list |
| `maxIssueWeight` | Int | Maximum weight of issues in the list |
| `milestone` | Milestone | Milestone of the list |
| `position` | Int | Position of list within the board |
| `title` | String! | Title of the list |
| `totalWeight` | Int | Total weight of all issues in the list |

### BoardListCreatePayload

Autogenerated return type of BoardListCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `list` | BoardList | List of the issue board. |

### BoardListUpdateLimitMetricsPayload

Autogenerated return type of BoardListUpdateLimitMetrics.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `list` | BoardList | The updated list |

### Branch

| Field | Type | Description |
| ----- | ---- | ----------- |
| `commit` | Commit | Commit for the branch |
| `name` | String! | Name of the branch |

### BurnupChartDailyTotals

Represents the total number of issues and their weights for a particular day.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `completedCount` | Int! | Number of closed issues as of this day |
| `completedWeight` | Int! | Total weight of closed issues as of this day |
| `date` | ISO8601Date! | Date for burnup totals |
| `scopeCount` | Int! | Number of issues as of this day |
| `scopeWeight` | Int! | Total weight of issues as of this day |

### CiBuildNeed

| Field | Type | Description |
| ----- | ---- | ----------- |
| `name` | String | Name of the job we need to complete. |

### CiConfig

| Field | Type | Description |
| ----- | ---- | ----------- |
| `errors` | String! => Array | Linting errors |
| `mergedYaml` | String | Merged CI config YAML |
| `stages` | CiConfigStageConnection | Stages of the pipeline |
| `status` | CiConfigStatus | Status of linting, can be either valid or invalid |

### CiConfigGroup

| Field | Type | Description |
| ----- | ---- | ----------- |
| `jobs` | CiConfigJobConnection | Jobs in group |
| `name` | String | Name of the job group |
| `size` | Int | Size of the job group |

### CiConfigJob

| Field | Type | Description |
| ----- | ---- | ----------- |
| `groupName` | String | Name of the job group |
| `name` | String | Name of the job |
| `needs` | CiConfigNeedConnection | Builds that must complete before the jobs run |
| `stage` | String | Name of the job stage |

### CiConfigNeed

| Field | Type | Description |
| ----- | ---- | ----------- |
| `name` | String | Name of the need |

### CiConfigStage

| Field | Type | Description |
| ----- | ---- | ----------- |
| `groups` | CiConfigGroupConnection | Groups of jobs for the stage |
| `name` | String | Name of the stage |

### CiGroup

| Field | Type | Description |
| ----- | ---- | ----------- |
| `detailedStatus` | DetailedStatus | Detailed status of the group |
| `jobs` | CiJobConnection | Jobs in group |
| `name` | String | Name of the job group |
| `size` | Int | Size of the group |

### CiJob

| Field | Type | Description |
| ----- | ---- | ----------- |
| `artifacts` | CiJobArtifactConnection | Artifacts generated by the job |
| `detailedStatus` | DetailedStatus | Detailed status of the job |
| `name` | String | Name of the job |
| `needs` | CiBuildNeedConnection | References to builds that must complete before the jobs run |
| `pipeline` | Pipeline | Pipeline the job belongs to |
| `scheduledAt` | Time | Schedule for the build |

### CiJobArtifact

| Field | Type | Description |
| ----- | ---- | ----------- |
| `downloadPath` | String | URL for downloading the artifact's file |
| `fileType` | JobArtifactFileType | File type of the artifact |

### CiStage

| Field | Type | Description |
| ----- | ---- | ----------- |
| `detailedStatus` | DetailedStatus | Detailed status of the stage |
| `groups` | CiGroupConnection | Group of jobs for the stage |
| `name` | String | Name of the stage |

### ClusterAgent

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time | Timestamp the cluster agent was created |
| `id` | ID! | ID of the cluster agent |
| `name` | String | Name of the cluster agent |
| `project` | Project | The project this cluster agent is associated with |
| `tokens` | ClusterAgentTokenConnection | Tokens associated with the cluster agent |
| `updatedAt` | Time | Timestamp the cluster agent was updated |

### ClusterAgentDeletePayload

Autogenerated return type of ClusterAgentDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### ClusterAgentToken

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clusterAgent` | ClusterAgent | Cluster agent this token is associated with |
| `createdAt` | Time | Timestamp the token was created |
| `id` | ClustersAgentTokenID! | Global ID of the token |

### ClusterAgentTokenCreatePayload

Autogenerated return type of ClusterAgentTokenCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `secret` | String | Token secret value. Make sure you save it - you won't be able to access it again |
| `token` | ClusterAgentToken | Token created after mutation |

### ClusterAgentTokenDeletePayload

Autogenerated return type of ClusterAgentTokenDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### CodeCoverageActivity

Represents the code coverage activity for a group.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `averageCoverage` | Float | Average percentage of the different code coverage results available for the group. |
| `coverageCount` | Int | Number of different code coverage results available for the group. |
| `date` | Date! | Date when the code coverage was created. |
| `projectCount` | Int | Number of projects with code coverage results for the group. |

### CodeCoverageSummary

Represents the code coverage summary for a project.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `averageCoverage` | Float | Average percentage of the different code coverage results available for the project. |
| `coverageCount` | Int | Number of different code coverage results available. |
| `lastUpdatedOn` | Date | Latest date when the code coverage was created for the project. |

### Commit

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | User | Author of the commit |
| `authorGravatar` | String | Commit authors gravatar |
| `authorName` | String | Commit authors name |
| `authoredDate` | Time | Timestamp of when the commit was authored |
| `description` | String | Description of the commit message |
| `descriptionHtml` | String | The GitLab Flavored Markdown rendering of `description` |
| `id` | ID! | ID (global ID) of the commit |
| `message` | String | Raw commit message |
| `pipelines` | PipelineConnection | Pipelines of the commit ordered latest first |
| `sha` | String! | SHA1 ID of the commit |
| `shortId` | String! | Short SHA1 ID of the commit |
| `signatureHtml` | String | Rendered HTML of the commit signature |
| `title` | String | Title of the commit message |
| `titleHtml` | String | The GitLab Flavored Markdown rendering of `title` |
| `webPath` | String! | Web path of the commit |
| `webUrl` | String! | Web URL of the commit |

### CommitCreatePayload

Autogenerated return type of CommitCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `commit` | Commit | The commit after mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### ComplianceFramework

Represents a ComplianceFramework associated with a Project.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `color` | String! | Hexadecimal representation of compliance framework's label color |
| `description` | String! | Description of the compliance framework |
| `id` | ID! | Compliance framework ID |
| `name` | String! | Name of the compliance framework |

### ConfigureSastPayload

Autogenerated return type of ConfigureSast.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `status` | String! | Status of creating the commit for the supplied SAST CI configuration |
| `successPath` | String | Redirect path to use when the response is successful |

### ContainerExpirationPolicy

A tag expiration policy designed to keep only the images that matter most.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cadence` | ContainerExpirationPolicyCadenceEnum! | This container expiration policy schedule |
| `createdAt` | Time! | Timestamp of when the container expiration policy was created |
| `enabled` | Boolean! | Indicates whether this container expiration policy is enabled |
| `keepN` | ContainerExpirationPolicyKeepEnum | Number of tags to retain |
| `nameRegex` | UntrustedRegexp | Tags with names matching this regex pattern will expire |
| `nameRegexKeep` | UntrustedRegexp | Tags with names matching this regex pattern will be preserved |
| `nextRunAt` | Time | Next time that this container expiration policy will get executed |
| `olderThan` | ContainerExpirationPolicyOlderThanEnum | Tags older that this will expire |
| `updatedAt` | Time! | Timestamp of when the container expiration policy was updated |

### ContainerRepository

A container repository.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `canDelete` | Boolean! | Can the current user delete the container repository. |
| `createdAt` | Time! | Timestamp when the container repository was created. |
| `expirationPolicyCleanupStatus` | ContainerRepositoryCleanupStatus | The tags cleanup status for the container repository. |
| `expirationPolicyStartedAt` | Time | Timestamp when the cleanup done by the expiration policy was started on the container repository. |
| `id` | ID! | ID of the container repository. |
| `location` | String! | URL of the container repository. |
| `name` | String! | Name of the container repository. |
| `path` | String! | Path of the container repository. |
| `project` | Project! | Project of the container registry |
| `status` | ContainerRepositoryStatus | Status of the container repository. |
| `tagsCount` | Int! | Number of tags associated with this image. |
| `updatedAt` | Time! | Timestamp when the container repository was updated. |

### ContainerRepositoryDetails

Details of a container repository.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `canDelete` | Boolean! | Can the current user delete the container repository. |
| `createdAt` | Time! | Timestamp when the container repository was created. |
| `expirationPolicyCleanupStatus` | ContainerRepositoryCleanupStatus | The tags cleanup status for the container repository. |
| `expirationPolicyStartedAt` | Time | Timestamp when the cleanup done by the expiration policy was started on the container repository. |
| `id` | ID! | ID of the container repository. |
| `location` | String! | URL of the container repository. |
| `name` | String! | Name of the container repository. |
| `path` | String! | Path of the container repository. |
| `project` | Project! | Project of the container registry |
| `status` | ContainerRepositoryStatus | Status of the container repository. |
| `tags` | ContainerRepositoryTagConnection | Tags of the container repository |
| `tagsCount` | Int! | Number of tags associated with this image. |
| `updatedAt` | Time! | Timestamp when the container repository was updated. |

### ContainerRepositoryTag

A tag from a container repository.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `canDelete` | Boolean! | Can the current user delete this tag. |
| `createdAt` | Time | Timestamp when the tag was created. |
| `digest` | String | Digest of the tag. |
| `location` | String! | URL of the tag. |
| `name` | String! | Name of the tag. |
| `path` | String! | Path of the tag. |
| `revision` | String | Revision of the tag. |
| `shortRevision` | String | Short revision of the tag. |
| `totalSize` | BigInt | The size of the tag. |

### CreateAlertIssuePayload

Autogenerated return type of CreateAlertIssue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `alert` | AlertManagementAlert | The alert after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue created after mutation. |
| `todo` | Todo | The todo after mutation. |

### CreateAnnotationPayload

Autogenerated return type of CreateAnnotation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `annotation` | MetricsDashboardAnnotation | The created annotation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### CreateBoardPayload

Autogenerated return type of CreateBoard.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `board` | Board | The board after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### CreateBranchPayload

Autogenerated return type of CreateBranch.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `branch` | Branch | Branch after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### CreateClusterAgentPayload

Autogenerated return type of CreateClusterAgent.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `clusterAgent` | ClusterAgent | Cluster agent created after mutation |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### CreateComplianceFrameworkPayload

Autogenerated return type of CreateComplianceFramework.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `framework` | ComplianceFramework | The created compliance framework. |

### CreateCustomEmojiPayload

Autogenerated return type of CreateCustomEmoji.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `customEmoji` | CustomEmoji | The new custom emoji. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### CreateDevopsAdoptionSegmentPayload

Autogenerated return type of CreateDevopsAdoptionSegment.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `segment` | DevopsAdoptionSegment | The segment after mutation |

### CreateDiffNotePayload

Autogenerated return type of CreateDiffNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `note` | Note | The note after mutation. |

### CreateEpicPayload

Autogenerated return type of CreateEpic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `epic` | Epic | The created epic |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### CreateImageDiffNotePayload

Autogenerated return type of CreateImageDiffNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `note` | Note | The note after mutation. |

### CreateIssuePayload

Autogenerated return type of CreateIssue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### CreateIterationPayload

Autogenerated return type of CreateIteration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `iteration` | Iteration | The created iteration |

### CreateNotePayload

Autogenerated return type of CreateNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `note` | Note | The note after mutation. |

### CreateRequirementPayload

Autogenerated return type of CreateRequirement.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `requirement` | Requirement | Requirement after mutation |

### CreateSnippetPayload

Autogenerated return type of CreateSnippet.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `snippet` | Snippet | The snippet after mutation. |
| `spam` | Boolean | Indicates whether the operation returns a record detected as spam. |

### CreateTestCasePayload

Autogenerated return type of CreateTestCase.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `testCase` | Issue | The test case created |

### CustomEmoji

A custom emoji uploaded by user.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `external` | Boolean! | Whether the emoji is an external link |
| `id` | CustomEmojiID! | The ID of the emoji |
| `name` | String! | The name of the emoji |
| `url` | String! | The link to file of the emoji |

### DastOnDemandScanCreatePayload

Autogenerated return type of DastOnDemandScanCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `pipelineUrl` | String | URL of the pipeline that was created. |

### DastScannerProfile

Represents a DAST scanner profile.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `editPath` | String | Relative web path to the edit page of a scanner profile |
| `globalId` **{warning-solid}** | DastScannerProfileID! | **Deprecated:** Use `id`. Deprecated in 13.6. |
| `id` | DastScannerProfileID! | ID of the DAST scanner profile |
| `profileName` | String | Name of the DAST scanner profile |
| `scanType` | DastScanTypeEnum | Indicates the type of DAST scan that will run. Either a Passive Scan or an Active Scan. |
| `showDebugMessages` | Boolean! | Indicates if debug messages should be included in DAST console output. True to include the debug messages. |
| `spiderTimeout` | Int | The maximum number of minutes allowed for the spider to traverse the site |
| `targetTimeout` | Int | The maximum number of seconds allowed for the site under test to respond to a request |
| `useAjaxSpider` | Boolean! | Indicates if the AJAX spider should be used to crawl the target site. True to run the AJAX spider in addition to the traditional spider, and false to run only the traditional spider. |

### DastScannerProfileCreatePayload

Autogenerated return type of DastScannerProfileCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `globalId` **{warning-solid}** | DastScannerProfileID | **Deprecated:** Use `id`. Deprecated in 13.6. |
| `id` | DastScannerProfileID | ID of the scanner profile. |

### DastScannerProfileDeletePayload

Autogenerated return type of DastScannerProfileDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### DastScannerProfileUpdatePayload

Autogenerated return type of DastScannerProfileUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `id` | DastScannerProfileID | ID of the scanner profile. |

### DastSiteProfile

Represents a DAST Site Profile.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `editPath` | String | Relative web path to the edit page of a site profile |
| `id` | DastSiteProfileID! | ID of the site profile |
| `normalizedTargetUrl` | String | Normalized URL of the target to be scanned |
| `profileName` | String | The name of the site profile |
| `targetUrl` | String | The URL of the target to be scanned |
| `userPermissions` | DastSiteProfilePermissions! | Permissions for the current user on the resource |
| `validationStatus` | DastSiteProfileValidationStatusEnum | The current validation status of the site profile |

### DastSiteProfileCreatePayload

Autogenerated return type of DastSiteProfileCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `id` | DastSiteProfileID | ID of the site profile. |

### DastSiteProfileDeletePayload

Autogenerated return type of DastSiteProfileDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### DastSiteProfilePermissions

Check permissions for the current user on site profile.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createOnDemandDastScan` | Boolean! | Indicates the user can perform `create_on_demand_dast_scan` on this resource |

### DastSiteProfileUpdatePayload

Autogenerated return type of DastSiteProfileUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `id` | DastSiteProfileID | ID of the site profile. |

### DastSiteTokenCreatePayload

Autogenerated return type of DastSiteTokenCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `id` | DastSiteTokenID | ID of the site token. |
| `status` | DastSiteProfileValidationStatusEnum | The current validation status of the target. |
| `token` | String | Token string. |

### DastSiteValidation

Represents a DAST Site Validation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `id` | DastSiteValidationID! | Global ID of the site validation |
| `normalizedTargetUrl` | String | Normalized URL of the target to be validated |
| `status` | DastSiteProfileValidationStatusEnum! | Status of the site validation |

### DastSiteValidationCreatePayload

Autogenerated return type of DastSiteValidationCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `id` | DastSiteValidationID | ID of the site validation. |
| `status` | DastSiteProfileValidationStatusEnum | The current validation status. |

### DeleteAnnotationPayload

Autogenerated return type of DeleteAnnotation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### DeleteDevopsAdoptionSegmentPayload

Autogenerated return type of DeleteDevopsAdoptionSegment.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### DeleteJobsResponse

The response from the AdminSidekiqQueuesDeleteJobs mutation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `completed` | Boolean | Whether or not the entire queue was processed in time; if not, retrying the same request is safe |
| `deletedJobs` | Int | The number of matching jobs deleted |
| `queueSize` | Int | The queue size after processing |

### Design

A single design.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `currentUserTodos` | TodoConnection! | Todos for the current user |
| `diffRefs` | DiffRefs! | The diff refs for this design |
| `discussions` | DiscussionConnection! | All discussions on this noteable |
| `event` | DesignVersionEvent! | How this design was changed in the current version |
| `filename` | String! | The filename of the design |
| `fullPath` | String! | The full path to the design file |
| `id` | ID! | The ID of this design |
| `image` | String! | The URL of the full-sized image |
| `imageV432x230` | String | The URL of the design resized to fit within the bounds of 432x230. This will be `null` if the image has not been generated |
| `issue` | Issue! | The issue the design belongs to |
| `notes` | NoteConnection! | All notes on this noteable |
| `notesCount` | Int! | The total count of user-created notes for this design |
| `project` | Project! | The project the design belongs to |
| `versions` | DesignVersionConnection! | All versions related to this design ordered newest first |

### DesignAtVersion

A design pinned to a specific version. The image field reflects the design as of the associated version.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `design` | Design! | The underlying design |
| `diffRefs` | DiffRefs! | The diff refs for this design |
| `event` | DesignVersionEvent! | How this design was changed in the current version |
| `filename` | String! | The filename of the design |
| `fullPath` | String! | The full path to the design file |
| `id` | ID! | The ID of this design |
| `image` | String! | The URL of the full-sized image |
| `imageV432x230` | String | The URL of the design resized to fit within the bounds of 432x230. This will be `null` if the image has not been generated |
| `issue` | Issue! | The issue the design belongs to |
| `notesCount` | Int! | The total count of user-created notes for this design |
| `project` | Project! | The project the design belongs to |
| `version` | DesignVersion! | The version this design-at-versions is pinned to |

### DesignCollection

A collection of designs.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `copyState` | DesignCollectionCopyState | Copy state of the design collection |
| `design` | Design | Find a specific design |
| `designAtVersion` | DesignAtVersion | Find a design as of a version |
| `designs` | DesignConnection! | All designs for the design collection |
| `issue` | Issue! | Issue associated with the design collection |
| `project` | Project! | Project associated with the design collection |
| `version` | DesignVersion | A specific version |
| `versions` | DesignVersionConnection! | All versions related to all designs, ordered newest first |

### DesignManagement

| Field | Type | Description |
| ----- | ---- | ----------- |
| `designAtVersion` | DesignAtVersion | Find a design as of a version |
| `version` | DesignVersion | Find a version |

### DesignManagementDeletePayload

Autogenerated return type of DesignManagementDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `version` | DesignVersion | The new version in which the designs are deleted. |

### DesignManagementMovePayload

Autogenerated return type of DesignManagementMove.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `designCollection` | DesignCollection | The current state of the collection. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### DesignManagementUploadPayload

Autogenerated return type of DesignManagementUpload.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `designs` | Design! => Array | The designs that were uploaded by the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `skippedDesigns` | Design! => Array | Any designs that were skipped from the upload due to there being no change to their content since their last version |

### DesignVersion

A specific version in which designs were added, modified or deleted.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `designAtVersion` | DesignAtVersion! | A particular design as of this version, provided it is visible at this version |
| `designs` | DesignConnection! | All designs that were changed in the version |
| `designsAtVersion` | DesignAtVersionConnection! | All designs that are visible at this version, as of this version |
| `id` | ID! | ID of the design version |
| `sha` | ID! | SHA of the design version |

### DestroyBoardListPayload

Autogenerated return type of DestroyBoardList.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `list` | BoardList | The list after mutation. |

### DestroyBoardPayload

Autogenerated return type of DestroyBoard.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `board` | Board | The board after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### DestroyComplianceFrameworkPayload

Autogenerated return type of DestroyComplianceFramework.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### DestroyContainerRepositoryPayload

Autogenerated return type of DestroyContainerRepository.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `containerRepository` | ContainerRepository! | The container repository policy after scheduling the deletion. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### DestroyContainerRepositoryTagsPayload

Autogenerated return type of DestroyContainerRepositoryTags.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `deletedTagNames` | String! => Array | Deleted container repository tags. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### DestroyNotePayload

Autogenerated return type of DestroyNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `note` | Note | The note after mutation. |

### DestroySnippetPayload

Autogenerated return type of DestroySnippet.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `snippet` | Snippet | The snippet after mutation. |

### DetailedStatus

| Field | Type | Description |
| ----- | ---- | ----------- |
| `action` | StatusAction | Action information for the status. This includes method, button title, icon, path, and title |
| `detailsPath` | String | Path of the details for the status |
| `favicon` | String | Favicon of the status |
| `group` | String | Group of the status |
| `hasDetails` | Boolean | Indicates if the status has further details |
| `icon` | String | Icon of the status |
| `label` | String | Label of the status |
| `text` | String | Text of the status |
| `tooltip` | String | Tooltip associated with the status |

### DevopsAdoptionSegment

Segment.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `groups` | Group! => Array | Assigned groups |
| `id` | ID! | ID of the segment |
| `latestSnapshot` | DevopsAdoptionSnapshot | The latest adoption metrics for the segment |
| `name` | String! | Name of the segment |

### DevopsAdoptionSnapshot

Snapshot.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `deploySucceeded` | Boolean! | At least one deployment succeeded |
| `endTime` | Time! | The end time for the snapshot where the data points were collected |
| `issueOpened` | Boolean! | At least one issue was opened |
| `mergeRequestApproved` | Boolean! | At least one merge request was approved |
| `mergeRequestOpened` | Boolean! | At least one merge request was opened |
| `pipelineSucceeded` | Boolean! | At least one pipeline succeeded |
| `recordedAt` | Time! | The time the snapshot was recorded |
| `runnerConfigured` | Boolean! | At least one runner was used |
| `securityScanSucceeded` | Boolean! | At least one security scan succeeded |
| `startTime` | Time! | The start time for the snapshot where the data points were collected |

### DiffPosition

| Field | Type | Description |
| ----- | ---- | ----------- |
| `diffRefs` | DiffRefs! | Information about the branch, HEAD, and base at the time of commenting |
| `filePath` | String! | Path of the file that was changed |
| `height` | Int | Total height of the image |
| `newLine` | Int | Line on HEAD SHA that was changed |
| `newPath` | String | Path of the file on the HEAD SHA |
| `oldLine` | Int | Line on start SHA that was changed |
| `oldPath` | String | Path of the file on the start SHA |
| `positionType` | DiffPositionType! | Type of file the position refers to |
| `width` | Int | Total width of the image |
| `x` | Int | X position of the note |
| `y` | Int | Y position of the note |

### DiffRefs

| Field | Type | Description |
| ----- | ---- | ----------- |
| `baseSha` | String | Merge base of the branch the comment was made on |
| `headSha` | String! | SHA of the HEAD at the time the comment was made |
| `startSha` | String! | SHA of the branch being compared against |

### DiffStats

Changes to a single file.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `additions` | Int! | Number of lines added to this file |
| `deletions` | Int! | Number of lines deleted from this file |
| `path` | String! | File path, relative to repository root |

### DiffStatsSummary

Aggregated summary of changes.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `additions` | Int! | Number of lines added |
| `changes` | Int! | Number of lines changed |
| `deletions` | Int! | Number of lines deleted |
| `fileCount` | Int! | Number of files changed |

### Discussion

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time! | Timestamp of the discussion's creation |
| `id` | ID! | ID of this discussion |
| `notes` | NoteConnection! | All notes in the discussion |
| `replyId` | ID! | ID used to reply to this discussion |
| `resolvable` | Boolean! | Indicates if the object can be resolved |
| `resolved` | Boolean! | Indicates if the object is resolved |
| `resolvedAt` | Time | Timestamp of when the object was resolved |
| `resolvedBy` | User | User who resolved the object |

### DiscussionToggleResolvePayload

Autogenerated return type of DiscussionToggleResolve.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `discussion` | Discussion | The discussion after mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### DismissVulnerabilityPayload

Autogenerated return type of DismissVulnerability.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `vulnerability` | Vulnerability | The vulnerability after dismissal |

### Environment

Describes where code is deployed for a project.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `id` | ID! | ID of the environment |
| `latestOpenedMostSevereAlert` | AlertManagementAlert | The most severe open alert for the environment. If multiple alerts have equal severity, the most recent is returned |
| `metricsDashboard` | MetricsDashboard | Metrics dashboard schema for the environment |
| `name` | String! | Human-readable name of the environment |
| `path` | String! | The path to the environment. |
| `state` | String! | State of the environment, for example: available/stopped |

### EnvironmentsCanaryIngressUpdatePayload

Autogenerated return type of EnvironmentsCanaryIngressUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### Epic

Represents an epic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | User! | Author of the epic |
| `children` | EpicConnection | Children (sub-epics) of the epic |
| `closedAt` | Time | Timestamp of when the epic was closed |
| `confidential` | Boolean | Indicates if the epic is confidential |
| `createdAt` | Time | Timestamp of when the epic was created |
| `currentUserTodos` | TodoConnection! | Todos for the current user |
| `descendantCounts` | EpicDescendantCount | Number of open and closed descendant epics and issues |
| `descendantWeightSum` | EpicDescendantWeights | Total weight of open and closed issues in the epic and its descendants |
| `description` | String | Description of the epic |
| `discussions` | DiscussionConnection! | All discussions on this noteable |
| `downvotes` | Int! | Number of downvotes the epic has received |
| `dueDate` | Time | Due date of the epic |
| `dueDateFixed` | Time | Fixed due date of the epic |
| `dueDateFromMilestones` | Time | Inherited due date of the epic from milestones |
| `dueDateIsFixed` | Boolean | Indicates if the due date has been manually set |
| `group` | Group! | Group to which the epic belongs |
| `hasChildren` | Boolean! | Indicates if the epic has children |
| `hasIssues` | Boolean! | Indicates if the epic has direct issues |
| `hasParent` | Boolean! | Indicates if the epic has a parent epic |
| `healthStatus` | EpicHealthStatus | Current health status of the epic |
| `id` | ID! | ID of the epic |
| `iid` | ID! | Internal ID of the epic |
| `issues` | EpicIssueConnection | A list of issues associated with the epic |
| `labels` | LabelConnection | Labels assigned to the epic |
| `notes` | NoteConnection! | All notes on this noteable |
| `parent` | Epic | Parent epic of the epic |
| `participants` | UserConnection | List of participants for the epic |
| `reference` | String! | Internal reference of the epic. Returned in shortened format by default |
| `relationPath` | String | URI path of the epic-issue relationship |
| `relativePosition` | Int | The relative position of the epic in the epic tree |
| `startDate` | Time | Start date of the epic |
| `startDateFixed` | Time | Fixed start date of the epic |
| `startDateFromMilestones` | Time | Inherited start date of the epic from milestones |
| `startDateIsFixed` | Boolean | Indicates if the start date has been manually set |
| `state` | EpicState! | State of the epic |
| `subscribed` | Boolean! | Indicates the currently logged in user is subscribed to the epic |
| `title` | String | Title of the epic |
| `updatedAt` | Time | Timestamp of when the epic was updated |
| `upvotes` | Int! | Number of upvotes the epic has received |
| `userDiscussionsCount` | Int! | Number of user discussions in the epic |
| `userNotesCount` | Int! | Number of user notes of the epic |
| `userPermissions` | EpicPermissions! | Permissions for the current user on the resource |
| `webPath` | String! | Web path of the epic |
| `webUrl` | String! | Web URL of the epic |

### EpicAddIssuePayload

Autogenerated return type of EpicAddIssue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `epic` | Epic | The epic after mutation |
| `epicIssue` | EpicIssue | The epic-issue relation |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### EpicBoard

Represents an epic board.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `id` | BoardsEpicBoardID! | Global ID of the board. |
| `lists` | EpicListConnection | Epic board lists. |
| `name` | String | Name of the board. |

### EpicDescendantCount

Counts of descendent epics.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `closedEpics` | Int | Number of closed child epics |
| `closedIssues` | Int | Number of closed epic issues |
| `openedEpics` | Int | Number of opened child epics |
| `openedIssues` | Int | Number of opened epic issues |

### EpicDescendantWeights

Total weight of open and closed descendant issues.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `closedIssues` | Int | Total weight of completed (closed) issues in this epic, including epic descendants |
| `openedIssues` | Int | Total weight of opened issues in this epic, including epic descendants |

### EpicHealthStatus

Health status of child issues.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `issuesAtRisk` | Int | Number of issues at risk |
| `issuesNeedingAttention` | Int | Number of issues that need attention |
| `issuesOnTrack` | Int | Number of issues on track |

### EpicIssue

Relationship between an epic and an issue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `alertManagementAlert` | AlertManagementAlert | Alert associated to this issue |
| `assignees` | UserConnection | Assignees of the issue |
| `author` | User! | User that created the issue |
| `blocked` | Boolean! | Indicates the issue is blocked. |
| `blockedByCount` | Int | Count of issues blocking this issue. |
| `closedAt` | Time | Timestamp of when the issue was closed |
| `confidential` | Boolean! | Indicates the issue is confidential |
| `createNoteEmail` | String | User specific email address for the issue |
| `createdAt` | Time! | Timestamp of when the issue was created |
| `currentUserTodos` | TodoConnection! | Todos for the current user |
| `description` | String | Description of the issue |
| `descriptionHtml` | String | The GitLab Flavored Markdown rendering of `description` |
| `designCollection` | DesignCollection | Collection of design images associated with this issue |
| `discussionLocked` | Boolean! | Indicates discussion is locked on the issue |
| `discussions` | DiscussionConnection! | All discussions on this noteable |
| `downvotes` | Int! | Number of downvotes the issue has received |
| `dueDate` | Time | Due date of the issue |
| `emailsDisabled` | Boolean! | Indicates if a project has email notifications disabled: `true` if email notifications are disabled |
| `epic` | Epic | Epic to which this issue belongs. |
| `epicIssueId` | ID! | ID of the epic-issue relation |
| `healthStatus` | HealthStatus | Current health status. |
| `humanTimeEstimate` | String | Human-readable time estimate of the issue |
| `humanTotalTimeSpent` | String | Human-readable total time reported as spent on the issue |
| `id` | ID | Global ID of the epic-issue relation |
| `iid` | ID! | Internal ID of the issue |
| `iteration` | Iteration | Iteration of the issue. |
| `labels` | LabelConnection | Labels of the issue |
| `metricImages` | MetricImage! => Array | Metric images associated to the issue. |
| `milestone` | Milestone | Milestone of the issue |
| `moved` | Boolean | Indicates if issue got moved from other project |
| `movedTo` | Issue | Updated Issue after it got moved to another project |
| `notes` | NoteConnection! | All notes on this noteable |
| `participants` | UserConnection | List of participants in the issue |
| `reference` | String! | Internal reference of the issue. Returned in shortened format by default |
| `relationPath` | String | URI path of the epic-issue relation |
| `relativePosition` | Int | Relative position of the issue (used for positioning in epic tree and issue boards) |
| `severity` | IssuableSeverity | Severity level of the incident |
| `slaDueAt` | Time | Timestamp of when the issue SLA expires. |
| `state` | IssueState! | State of the issue |
| `statusPagePublishedIncident` | Boolean | Indicates whether an issue is published to the status page. |
| `subscribed` | Boolean! | Indicates the currently logged in user is subscribed to the issue |
| `taskCompletionStatus` | TaskCompletionStatus! | Task completion status of the issue |
| `timeEstimate` | Int! | Time estimate of the issue |
| `title` | String! | Title of the issue |
| `titleHtml` | String | The GitLab Flavored Markdown rendering of `title` |
| `totalTimeSpent` | Int! | Total time reported as spent on the issue |
| `type` | IssueType | Type of the issue |
| `updatedAt` | Time! | Timestamp of when the issue was last updated |
| `updatedBy` | User | User that last updated the issue |
| `upvotes` | Int! | Number of upvotes the issue has received |
| `userDiscussionsCount` | Int! | Number of user discussions in the issue |
| `userNotesCount` | Int! | Number of user notes of the issue |
| `userPermissions` | IssuePermissions! | Permissions for the current user on the resource |
| `webPath` | String! | Web path of the issue |
| `webUrl` | String! | Web URL of the issue |
| `weight` | Int | Weight of the issue. |

### EpicList

Represents an epic board list.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `epics` | EpicConnection | List epics. |
| `id` | BoardsEpicListID! | Global ID of the board list. |
| `label` | Label | Label of the list. |
| `listType` | String! | Type of the list. |
| `position` | Int | Position of the list within the board. |
| `title` | String! | Title of the list. |

### EpicPermissions

Check permissions for the current user on an epic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminEpic` | Boolean! | Indicates the user can perform `admin_epic` on this resource |
| `awardEmoji` | Boolean! | Indicates the user can perform `award_emoji` on this resource |
| `createEpic` | Boolean! | Indicates the user can perform `create_epic` on this resource |
| `createNote` | Boolean! | Indicates the user can perform `create_note` on this resource |
| `destroyEpic` | Boolean! | Indicates the user can perform `destroy_epic` on this resource |
| `readEpic` | Boolean! | Indicates the user can perform `read_epic` on this resource |
| `readEpicIid` | Boolean! | Indicates the user can perform `read_epic_iid` on this resource |
| `updateEpic` | Boolean! | Indicates the user can perform `update_epic` on this resource |

### EpicSetSubscriptionPayload

Autogenerated return type of EpicSetSubscription.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `epic` | Epic | The epic after mutation |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### EpicTreeReorderPayload

Autogenerated return type of EpicTreeReorder.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### ExternalIssue

Represents an external issue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time | Timestamp of when the issue was created |
| `externalTracker` | String | Type of external tracker |
| `relativeReference` | String | Relative reference of the issue in the external tracker |
| `status` | String | Status of the issue in the external tracker |
| `title` | String | Title of the issue in the external tracker |
| `updatedAt` | Time | Timestamp of when the issue was updated |
| `webUrl` | String | URL to the issue in the external tracker |

### GeoNode

| Field | Type | Description |
| ----- | ---- | ----------- |
| `containerRepositoriesMaxCapacity` | Int | The maximum concurrency of container repository sync for this secondary node |
| `enabled` | Boolean | Indicates whether this Geo node is enabled |
| `filesMaxCapacity` | Int | The maximum concurrency of LFS/attachment backfill for this secondary node |
| `id` | ID! | ID of this GeoNode |
| `internalUrl` | String | The URL defined on the primary node that secondary nodes should use to contact it |
| `mergeRequestDiffRegistries` | MergeRequestDiffRegistryConnection | Find merge request diff registries on this Geo node |
| `minimumReverificationInterval` | Int | The interval (in days) in which the repository verification is valid. Once expired, it will be reverified |
| `name` | String | The unique identifier for this Geo node |
| `packageFileRegistries` | PackageFileRegistryConnection | Package file registries of the GeoNode |
| `primary` | Boolean | Indicates whether this Geo node is the primary |
| `reposMaxCapacity` | Int | The maximum concurrency of repository backfill for this secondary node |
| `selectiveSyncNamespaces` | NamespaceConnection | The namespaces that should be synced, if `selective_sync_type` == `namespaces` |
| `selectiveSyncShards` | String! => Array | The repository storages whose projects should be synced, if `selective_sync_type` == `shards` |
| `selectiveSyncType` | String | Indicates if syncing is limited to only specific groups, or shards |
| `snippetRepositoryRegistries` | SnippetRepositoryRegistryConnection | Find snippet repository registries on this Geo node |
| `syncObjectStorage` | Boolean | Indicates if this secondary node will replicate blobs in Object Storage |
| `terraformStateVersionRegistries` | TerraformStateVersionRegistryConnection | Find terraform state version registries on this Geo node |
| `url` | String | The user-facing URL for this Geo node |
| `verificationMaxCapacity` | Int | The maximum concurrency of repository verification for this secondary node |

### GrafanaIntegration

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time! | Timestamp of the issue's creation |
| `enabled` | Boolean! | Indicates whether Grafana integration is enabled |
| `grafanaUrl` | String! | URL for the Grafana host for the Grafana integration |
| `id` | ID! | Internal ID of the Grafana integration |
| `updatedAt` | Time! | Timestamp of the issue's last activity |

### Group

| Field | Type | Description |
| ----- | ---- | ----------- |
| `actualRepositorySizeLimit` | Float | Size limit for repositories in the namespace in bytes |
| `additionalPurchasedStorageSize` | Float | Additional storage purchased for the root namespace in bytes |
| `autoDevopsEnabled` | Boolean | Indicates whether Auto DevOps is enabled for all projects within this group |
| `avatarUrl` | String | Avatar URL of the group |
| `board` | Board | A single board of the group |
| `boards` | BoardConnection | Boards of the group |
| `codeCoverageActivities` | CodeCoverageActivityConnection | Represents the code coverage activity for this group |
| `complianceFrameworks` | ComplianceFrameworkConnection | Compliance frameworks available to projects in this namespace. Available only when feature flag `ff_custom_compliance_frameworks` is enabled. |
| `containerRepositories` | ContainerRepositoryConnection | Container repositories of the group |
| `containerRepositoriesCount` | Int! | Number of container repositories in the group |
| `containsLockedProjects` | Boolean! | Includes at least one project where the repository size exceeds the limit |
| `customEmoji` | CustomEmojiConnection | Custom emoji within this namespace Available only when feature flag `custom_emoji` is enabled. |
| `description` | String | Description of the namespace |
| `descriptionHtml` | String | The GitLab Flavored Markdown rendering of `description` |
| `emailsDisabled` | Boolean | Indicates if a group has email notifications disabled |
| `epic` | Epic | Find a single epic |
| `epicBoard` | EpicBoard | Find a single epic board |
| `epicBoards` | EpicBoardConnection | Find epic boards |
| `epics` | EpicConnection | Find epics |
| `epicsEnabled` | Boolean | Indicates if Epics are enabled for namespace |
| `fullName` | String! | Full name of the namespace |
| `fullPath` | ID! | Full path of the namespace |
| `groupMembers` | GroupMemberConnection | A membership of a user within this group |
| `groupTimelogsEnabled` | Boolean | Indicates if Group timelogs are enabled for namespace |
| `id` | ID! | ID of the namespace |
| `isTemporaryStorageIncreaseEnabled` | Boolean! | Status of the temporary storage increase |
| `issues` | IssueConnection | Issues for projects in this group |
| `iterations` | IterationConnection | Find iterations |
| `label` | Label | A label available on this group |
| `labels` | LabelConnection | Labels available on this group |
| `lfsEnabled` | Boolean | Indicates if Large File Storage (LFS) is enabled for namespace |
| `mentionsDisabled` | Boolean | Indicates if a group is disabled from getting mentioned |
| `mergeRequests` | MergeRequestConnection | Merge requests for projects in this group |
| `milestones` | MilestoneConnection | Milestones of the group |
| `name` | String! | Name of the namespace |
| `packageSettings` | PackageSettings | The package settings for the namespace |
| `parent` | Group | Parent group |
| `path` | String! | Path of the namespace |
| `projectCreationLevel` | String | The permission level required to create projects in the group |
| `projects` | ProjectConnection! | Projects within this namespace |
| `repositorySizeExcessProjectCount` | Int! | Number of projects in the root namespace where the repository size exceeds the limit |
| `requestAccessEnabled` | Boolean | Indicates if users can request access to namespace |
| `requireTwoFactorAuthentication` | Boolean | Indicates if all users in this group are required to set up two-factor authentication |
| `rootStorageStatistics` | RootStorageStatistics | Aggregated storage statistics of the namespace. Only available for root namespaces |
| `shareWithGroupLock` | Boolean | Indicates if sharing a project with another group within this group is prevented |
| `stats` | GroupStats | Group statistics |
| `storageSizeLimit` | Float | Total storage limit of the root namespace in bytes |
| `subgroupCreationLevel` | String | The permission level required to create subgroups within the group |
| `temporaryStorageIncreaseEndsOn` | Time | Date until the temporary storage increase is active |
| `timelogs` | TimelogConnection! | Time logged in issues by group members |
| `totalRepositorySize` | Float | Total repository size of all projects in the root namespace in bytes |
| `totalRepositorySizeExcess` | Float | Total excess repository size of all projects in the root namespace in bytes |
| `twoFactorGracePeriod` | Int | Time before two-factor authentication is enforced |
| `userPermissions` | GroupPermissions! | Permissions for the current user on the resource |
| `visibility` | String | Visibility of the namespace |
| `vulnerabilities` | VulnerabilityConnection | Vulnerabilities reported on the projects in the group and its subgroups |
| `vulnerabilitiesCountByDay` | VulnerabilitiesCountByDayConnection | Number of vulnerabilities per day for the projects in the group and its subgroups |
| `vulnerabilitiesCountByDayAndSeverity` **{warning-solid}** | VulnerabilitiesCountByDayAndSeverityConnection | **Deprecated:** Use `vulnerabilitiesCountByDay`. Deprecated in 13.3. |
| `vulnerabilityGrades` | VulnerableProjectsByGrade! => Array | Represents vulnerable project counts for each grade |
| `vulnerabilityScanners` | VulnerabilityScannerConnection | Vulnerability scanners reported on the project vulnerabilties of the group and its subgroups |
| `vulnerabilitySeveritiesCount` | VulnerabilitySeveritiesCount | Counts for each vulnerability severity in the group and its subgroups |
| `webUrl` | String! | Web URL of the group |

### GroupMember

Represents a Group Membership.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `accessLevel` | AccessLevel | GitLab::Access level |
| `createdAt` | Time | Date and time the membership was created |
| `createdBy` | User | User that authorized membership |
| `expiresAt` | Time | Date and time the membership expires |
| `group` | Group | Group that a User is a member of |
| `id` | ID! | ID of the member |
| `updatedAt` | Time | Date and time the membership was last updated |
| `user` | User! | User that is associated with the member object |
| `userPermissions` | GroupPermissions! | Permissions for the current user on the resource |

### GroupPermissions

| Field | Type | Description |
| ----- | ---- | ----------- |
| `readGroup` | Boolean! | Indicates the user can perform `read_group` on this resource |

### GroupReleaseStats

Contains release-related statistics about a group.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `releasesCount` | Int | Total number of releases in all descendant projects of the group. Will always return `null` if `group_level_release_statistics` feature flag is disabled |
| `releasesPercentage` | Int | Percentage of the group's descendant projects that have at least one release. Will always return `null` if `group_level_release_statistics` feature flag is disabled |

### GroupStats

Contains statistics about a group.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `releaseStats` | GroupReleaseStats | Statistics related to releases within the group |

### HttpIntegrationCreatePayload

Autogenerated return type of HttpIntegrationCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `integration` | AlertManagementHttpIntegration | The HTTP integration. |

### HttpIntegrationDestroyPayload

Autogenerated return type of HttpIntegrationDestroy.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `integration` | AlertManagementHttpIntegration | The HTTP integration. |

### HttpIntegrationResetTokenPayload

Autogenerated return type of HttpIntegrationResetToken.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `integration` | AlertManagementHttpIntegration | The HTTP integration. |

### HttpIntegrationUpdatePayload

Autogenerated return type of HttpIntegrationUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `integration` | AlertManagementHttpIntegration | The HTTP integration. |

### IncidentManagementOncallRotation

Describes an incident management on-call rotation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `id` | IncidentManagementOncallRotationID! | ID of the on-call rotation. |
| `length` | Int | Length of the on-call schedule, in the units specified by lengthUnit. |
| `lengthUnit` | OncallRotationUnitEnum | Unit of the on-call rotation length. |
| `name` | String! | Name of the on-call rotation. |
| `participants` | OncallParticipantTypeConnection | Participants of the on-call rotation. |
| `startsAt` | Time | Start date of the on-call rotation. |

### IncidentManagementOncallSchedule

Describes an incident management on-call schedule.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | String | Description of the on-call schedule |
| `iid` | ID! | Internal ID of the on-call schedule |
| `name` | String! | Name of the on-call schedule |
| `rotations` | IncidentManagementOncallRotationConnection! | On-call rotations for the on-call schedule |
| `timezone` | String! | Time zone of the on-call schedule |

### InstanceSecurityDashboard

| Field | Type | Description |
| ----- | ---- | ----------- |
| `projects` | ProjectConnection! | Projects selected in Instance Security Dashboard |
| `vulnerabilityGrades` | VulnerableProjectsByGrade! => Array | Represents vulnerable project counts for each grade |
| `vulnerabilityScanners` | VulnerabilityScannerConnection | Vulnerability scanners reported on the vulnerabilties from projects selected in Instance Security Dashboard |
| `vulnerabilitySeveritiesCount` | VulnerabilitySeveritiesCount | Counts for each vulnerability severity from projects selected in Instance Security Dashboard |

### InstanceStatisticsMeasurement

Represents a recorded measurement (object count) for the Admins.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | Int! | Object count |
| `identifier` | MeasurementIdentifier! | The type of objects being measured |
| `recordedAt` | Time | The time the measurement was recorded |

### Issue

| Field | Type | Description |
| ----- | ---- | ----------- |
| `alertManagementAlert` | AlertManagementAlert | Alert associated to this issue |
| `assignees` | UserConnection | Assignees of the issue |
| `author` | User! | User that created the issue |
| `blocked` | Boolean! | Indicates the issue is blocked. |
| `blockedByCount` | Int | Count of issues blocking this issue. |
| `closedAt` | Time | Timestamp of when the issue was closed |
| `confidential` | Boolean! | Indicates the issue is confidential |
| `createNoteEmail` | String | User specific email address for the issue |
| `createdAt` | Time! | Timestamp of when the issue was created |
| `currentUserTodos` | TodoConnection! | Todos for the current user |
| `description` | String | Description of the issue |
| `descriptionHtml` | String | The GitLab Flavored Markdown rendering of `description` |
| `designCollection` | DesignCollection | Collection of design images associated with this issue |
| `discussionLocked` | Boolean! | Indicates discussion is locked on the issue |
| `discussions` | DiscussionConnection! | All discussions on this noteable |
| `downvotes` | Int! | Number of downvotes the issue has received |
| `dueDate` | Time | Due date of the issue |
| `emailsDisabled` | Boolean! | Indicates if a project has email notifications disabled: `true` if email notifications are disabled |
| `epic` | Epic | Epic to which this issue belongs. |
| `healthStatus` | HealthStatus | Current health status. |
| `humanTimeEstimate` | String | Human-readable time estimate of the issue |
| `humanTotalTimeSpent` | String | Human-readable total time reported as spent on the issue |
| `id` | ID! | ID of the issue |
| `iid` | ID! | Internal ID of the issue |
| `iteration` | Iteration | Iteration of the issue. |
| `labels` | LabelConnection | Labels of the issue |
| `metricImages` | MetricImage! => Array | Metric images associated to the issue. |
| `milestone` | Milestone | Milestone of the issue |
| `moved` | Boolean | Indicates if issue got moved from other project |
| `movedTo` | Issue | Updated Issue after it got moved to another project |
| `notes` | NoteConnection! | All notes on this noteable |
| `participants` | UserConnection | List of participants in the issue |
| `reference` | String! | Internal reference of the issue. Returned in shortened format by default |
| `relativePosition` | Int | Relative position of the issue (used for positioning in epic tree and issue boards) |
| `severity` | IssuableSeverity | Severity level of the incident |
| `slaDueAt` | Time | Timestamp of when the issue SLA expires. |
| `state` | IssueState! | State of the issue |
| `statusPagePublishedIncident` | Boolean | Indicates whether an issue is published to the status page. |
| `subscribed` | Boolean! | Indicates the currently logged in user is subscribed to the issue |
| `taskCompletionStatus` | TaskCompletionStatus! | Task completion status of the issue |
| `timeEstimate` | Int! | Time estimate of the issue |
| `title` | String! | Title of the issue |
| `titleHtml` | String | The GitLab Flavored Markdown rendering of `title` |
| `totalTimeSpent` | Int! | Total time reported as spent on the issue |
| `type` | IssueType | Type of the issue |
| `updatedAt` | Time! | Timestamp of when the issue was last updated |
| `updatedBy` | User | User that last updated the issue |
| `upvotes` | Int! | Number of upvotes the issue has received |
| `userDiscussionsCount` | Int! | Number of user discussions in the issue |
| `userNotesCount` | Int! | Number of user notes of the issue |
| `userPermissions` | IssuePermissions! | Permissions for the current user on the resource |
| `webPath` | String! | Web path of the issue |
| `webUrl` | String! | Web URL of the issue |
| `weight` | Int | Weight of the issue. |

### IssueMoveListPayload

Autogenerated return type of IssueMoveList.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### IssueMovePayload

Autogenerated return type of IssueMove.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### IssuePermissions

Check permissions for the current user on a issue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminIssue` | Boolean! | Indicates the user can perform `admin_issue` on this resource |
| `createDesign` | Boolean! | Indicates the user can perform `create_design` on this resource |
| `createNote` | Boolean! | Indicates the user can perform `create_note` on this resource |
| `destroyDesign` | Boolean! | Indicates the user can perform `destroy_design` on this resource |
| `readDesign` | Boolean! | Indicates the user can perform `read_design` on this resource |
| `readIssue` | Boolean! | Indicates the user can perform `read_issue` on this resource |
| `reopenIssue` | Boolean! | Indicates the user can perform `reopen_issue` on this resource |
| `updateIssue` | Boolean! | Indicates the user can perform `update_issue` on this resource |

### IssueSetAssigneesPayload

Autogenerated return type of IssueSetAssignees.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### IssueSetConfidentialPayload

Autogenerated return type of IssueSetConfidential.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### IssueSetDueDatePayload

Autogenerated return type of IssueSetDueDate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### IssueSetEpicPayload

Autogenerated return type of IssueSetEpic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### IssueSetIterationPayload

Autogenerated return type of IssueSetIteration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### IssueSetLockedPayload

Autogenerated return type of IssueSetLocked.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### IssueSetSeverityPayload

Autogenerated return type of IssueSetSeverity.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### IssueSetSubscriptionPayload

Autogenerated return type of IssueSetSubscription.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### IssueSetWeightPayload

Autogenerated return type of IssueSetWeight.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### IssueStatusCountsType

Represents total number of issues for the represented statuses.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `all` | Int | Number of issues with status ALL for the project |
| `closed` | Int | Number of issues with status CLOSED for the project |
| `opened` | Int | Number of issues with status OPENED for the project |

### Iteration

Represents an iteration object.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time! | Timestamp of iteration creation |
| `description` | String | Description of the iteration |
| `descriptionHtml` | String | The GitLab Flavored Markdown rendering of `description` |
| `dueDate` | Time | Timestamp of the iteration due date |
| `id` | ID! | ID of the iteration |
| `iid` | ID! | Internal ID of the iteration |
| `report` | TimeboxReport | Historically accurate report about the timebox |
| `scopedPath` | String | Web path of the iteration, scoped to the query parent. Only valid for Project parents. Returns null in other contexts |
| `scopedUrl` | String | Web URL of the iteration, scoped to the query parent. Only valid for Project parents. Returns null in other contexts |
| `startDate` | Time | Timestamp of the iteration start date |
| `state` | IterationState! | State of the iteration |
| `title` | String! | Title of the iteration |
| `updatedAt` | Time! | Timestamp of last iteration update |
| `webPath` | String! | Web path of the iteration |
| `webUrl` | String! | Web URL of the iteration |

### JiraImport

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time | Timestamp of when the Jira import was created |
| `failedToImportCount` | Int! | Count of issues that failed to import |
| `importedIssuesCount` | Int! | Count of issues that were successfully imported |
| `jiraProjectKey` | String! | Project key for the imported Jira project |
| `scheduledAt` | Time | Timestamp of when the Jira import was scheduled |
| `scheduledBy` | User | User that started the Jira import |
| `totalIssueCount` | Int! | Total count of issues that were attempted to import |

### JiraImportStartPayload

Autogenerated return type of JiraImportStart.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `jiraImport` | JiraImport | The Jira import data after mutation. |

### JiraImportUsersPayload

Autogenerated return type of JiraImportUsers.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `jiraUsers` | JiraUser! => Array | Users returned from Jira, matched by email and name if possible. |

### JiraProject

| Field | Type | Description |
| ----- | ---- | ----------- |
| `key` | String! | Key of the Jira project |
| `name` | String | Name of the Jira project |
| `projectId` | Int! | ID of the Jira project |

### JiraService

| Field | Type | Description |
| ----- | ---- | ----------- |
| `active` | Boolean | Indicates if the service is active |
| `projects` | JiraProjectConnection | List of all Jira projects fetched through Jira REST API |
| `type` | String | Class name of the service |

### JiraUser

| Field | Type | Description |
| ----- | ---- | ----------- |
| `gitlabId` | Int | ID of the matched GitLab user |
| `gitlabName` | String | Name of the matched GitLab user |
| `gitlabUsername` | String | Username of the matched GitLab user |
| `jiraAccountId` | String! | Account ID of the Jira user |
| `jiraDisplayName` | String! | Display name of the Jira user |
| `jiraEmail` | String | Email of the Jira user, returned only for users with public emails |

### Label

| Field | Type | Description |
| ----- | ---- | ----------- |
| `color` | String! | Background color of the label |
| `description` | String | Description of the label (Markdown rendered as HTML for caching) |
| `descriptionHtml` | String | The GitLab Flavored Markdown rendering of `description` |
| `id` | ID! | Label ID |
| `textColor` | String! | Text color of the label |
| `title` | String! | Content of the label |

### LabelCreatePayload

Autogenerated return type of LabelCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `label` | Label | The label after mutation. |

### MarkAsSpamSnippetPayload

Autogenerated return type of MarkAsSpamSnippet.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `snippet` | Snippet | The snippet after mutation. |

### MergeRequest

| Field | Type | Description |
| ----- | ---- | ----------- |
| `allowCollaboration` | Boolean | Indicates if members of the target project can push to the fork |
| `approvalsLeft` | Int | Number of approvals left |
| `approvalsRequired` | Int | Number of approvals required |
| `approved` | Boolean! | Indicates if the merge request has all the required approvals. Returns true if no required approvals are configured. |
| `approvedBy` | UserConnection | Users who approved the merge request |
| `assignees` | UserConnection | Assignees of the merge request |
| `author` | User | User who created this merge request |
| `autoMergeEnabled` | Boolean! | Indicates if auto merge is enabled for the merge request |
| `autoMergeStrategy` | String | Selected auto merge strategy |
| `availableAutoMergeStrategies` | String! => Array | Array of available auto merge strategies |
| `commitCount` | Int | Number of commits in the merge request |
| `commitsWithoutMergeCommits` | CommitConnection | Merge request commits excluding merge commits |
| `conflicts` | Boolean! | Indicates if the merge request has conflicts |
| `createdAt` | Time! | Timestamp of when the merge request was created |
| `currentUserTodos` | TodoConnection! | Todos for the current user |
| `defaultMergeCommitMessage` | String | Default merge commit message of the merge request |
| `defaultMergeCommitMessageWithDescription` | String | Default merge commit message of the merge request with description |
| `defaultSquashCommitMessage` | String | Default squash commit message of the merge request |
| `description` | String | Description of the merge request (Markdown rendered as HTML for caching) |
| `descriptionHtml` | String | The GitLab Flavored Markdown rendering of `description` |
| `diffHeadSha` | String | Diff head SHA of the merge request |
| `diffRefs` | DiffRefs | References of the base SHA, the head SHA, and the start SHA for this merge request |
| `diffStats` | DiffStats! => Array | Details about which files were changed in this merge request |
| `diffStatsSummary` | DiffStatsSummary | Summary of which files were changed in this merge request |
| `discussionLocked` | Boolean! | Indicates if comments on the merge request are locked to members only |
| `discussions` | DiscussionConnection! | All discussions on this noteable |
| `downvotes` | Int! | Number of downvotes for the merge request |
| `forceRemoveSourceBranch` | Boolean | Indicates if the project settings will lead to source branch deletion after merge |
| `hasCi` | Boolean! | Indicates if the merge request has CI |
| `headPipeline` | Pipeline | The pipeline running on the branch HEAD of the merge request |
| `id` | ID! | ID of the merge request |
| `iid` | String! | Internal ID of the merge request |
| `inProgressMergeCommitSha` | String | Commit SHA of the merge request if merge is in progress |
| `labels` | LabelConnection | Labels of the merge request |
| `mergeCommitSha` | String | SHA of the merge request commit (set once merged) |
| `mergeError` | String | Error message due to a merge error |
| `mergeOngoing` | Boolean! | Indicates if a merge is currently occurring |
| `mergeStatus` | String | Status of the merge request |
| `mergeTrainsCount` | Int |  |
| `mergeUser` | User | User who merged this merge request |
| `mergeWhenPipelineSucceeds` | Boolean | Indicates if the merge has been set to be merged when its pipeline succeeds (MWPS) |
| `mergeable` | Boolean! | Indicates if the merge request is mergeable |
| `mergeableDiscussionsState` | Boolean | Indicates if all discussions in the merge request have been resolved, allowing the merge request to be merged |
| `mergedAt` | Time | Timestamp of when the merge request was merged, null if not merged |
| `milestone` | Milestone | The milestone of the merge request |
| `notes` | NoteConnection! | All notes on this noteable |
| `participants` | UserConnection | Participants in the merge request. This includes the author, assignees, reviewers, and users mentioned in notes. |
| `pipelines` | PipelineConnection | Pipelines for the merge request. Note: for performance reasons, no more than the most recent 500 pipelines will be returned. |
| `project` | Project! | Alias for target_project |
| `projectId` | Int! | ID of the merge request project |
| `rebaseCommitSha` | String | Rebase commit SHA of the merge request |
| `rebaseInProgress` | Boolean! | Indicates if there is a rebase currently in progress for the merge request |
| `reference` | String! | Internal reference of the merge request. Returned in shortened format by default |
| `reviewers` | UserConnection | Users from whom a review has been requested. |
| `securityAutoFix` | Boolean | Indicates if the merge request is created by @GitLab-Security-Bot. |
| `shouldBeRebased` | Boolean! | Indicates if the merge request will be rebased |
| `shouldRemoveSourceBranch` | Boolean | Indicates if the source branch of the merge request will be deleted after merge |
| `sourceBranch` | String! | Source branch of the merge request |
| `sourceBranchExists` | Boolean! | Indicates if the source branch of the merge request exists |
| `sourceBranchProtected` | Boolean! | Indicates if the source branch is protected |
| `sourceProject` | Project | Source project of the merge request |
| `sourceProjectId` | Int | ID of the merge request source project |
| `squash` | Boolean! | Indicates if squash on merge is enabled |
| `squashOnMerge` | Boolean! | Indicates if squash on merge is enabled |
| `state` | MergeRequestState! | State of the merge request |
| `subscribed` | Boolean! | Indicates if the currently logged in user is subscribed to this merge request |
| `targetBranch` | String! | Target branch of the merge request |
| `targetBranchExists` | Boolean! | Indicates if the target branch of the merge request exists |
| `targetProject` | Project! | Target project of the merge request |
| `targetProjectId` | Int! | ID of the merge request target project |
| `taskCompletionStatus` | TaskCompletionStatus! | Completion status of tasks |
| `timeEstimate` | Int! | Time estimate of the merge request |
| `title` | String! | Title of the merge request |
| `titleHtml` | String | The GitLab Flavored Markdown rendering of `title` |
| `totalTimeSpent` | Int! | Total time reported as spent on the merge request |
| `updatedAt` | Time! | Timestamp of when the merge request was last updated |
| `upvotes` | Int! | Number of upvotes for the merge request |
| `userDiscussionsCount` | Int | Number of user discussions in the merge request |
| `userNotesCount` | Int | User notes count of the merge request |
| `userPermissions` | MergeRequestPermissions! | Permissions for the current user on the resource |
| `webUrl` | String | Web URL of the merge request |
| `workInProgress` | Boolean! | Indicates if the merge request is a work in progress (WIP) |

### MergeRequestCreatePayload

Autogenerated return type of MergeRequestCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `mergeRequest` | MergeRequest | The merge request after mutation. |

### MergeRequestDiffRegistry

Represents the Geo sync and verification state of a Merge Request diff.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time | Timestamp when the MergeRequestDiffRegistry was created |
| `id` | ID! | ID of the MergeRequestDiffRegistry |
| `lastSyncFailure` | String | Error message during sync of the MergeRequestDiffRegistry |
| `lastSyncedAt` | Time | Timestamp of the most recent successful sync of the MergeRequestDiffRegistry |
| `mergeRequestDiffId` | ID! | ID of the Merge Request diff |
| `retryAt` | Time | Timestamp after which the MergeRequestDiffRegistry should be resynced |
| `retryCount` | Int | Number of consecutive failed sync attempts of the MergeRequestDiffRegistry |
| `state` | RegistryState | Sync state of the MergeRequestDiffRegistry |

### MergeRequestPermissions

Check permissions for the current user on a merge request.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminMergeRequest` | Boolean! | Indicates the user can perform `admin_merge_request` on this resource |
| `canMerge` | Boolean! | Indicates the user can perform `can_merge` on this resource |
| `cherryPickOnCurrentMergeRequest` | Boolean! | Indicates the user can perform `cherry_pick_on_current_merge_request` on this resource |
| `createNote` | Boolean! | Indicates the user can perform `create_note` on this resource |
| `pushToSourceBranch` | Boolean! | Indicates the user can perform `push_to_source_branch` on this resource |
| `readMergeRequest` | Boolean! | Indicates the user can perform `read_merge_request` on this resource |
| `removeSourceBranch` | Boolean! | Indicates the user can perform `remove_source_branch` on this resource |
| `revertOnCurrentMergeRequest` | Boolean! | Indicates the user can perform `revert_on_current_merge_request` on this resource |
| `updateMergeRequest` | Boolean! | Indicates the user can perform `update_merge_request` on this resource |

### MergeRequestSetAssigneesPayload

Autogenerated return type of MergeRequestSetAssignees.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `mergeRequest` | MergeRequest | The merge request after mutation. |

### MergeRequestSetLabelsPayload

Autogenerated return type of MergeRequestSetLabels.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `mergeRequest` | MergeRequest | The merge request after mutation. |

### MergeRequestSetLockedPayload

Autogenerated return type of MergeRequestSetLocked.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `mergeRequest` | MergeRequest | The merge request after mutation. |

### MergeRequestSetMilestonePayload

Autogenerated return type of MergeRequestSetMilestone.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `mergeRequest` | MergeRequest | The merge request after mutation. |

### MergeRequestSetSubscriptionPayload

Autogenerated return type of MergeRequestSetSubscription.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `mergeRequest` | MergeRequest | The merge request after mutation. |

### MergeRequestSetWipPayload

Autogenerated return type of MergeRequestSetWip.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `mergeRequest` | MergeRequest | The merge request after mutation. |

### MergeRequestUpdatePayload

Autogenerated return type of MergeRequestUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `mergeRequest` | MergeRequest | The merge request after mutation. |

### Metadata

| Field | Type | Description |
| ----- | ---- | ----------- |
| `revision` | String! | Revision |
| `version` | String! | Version |

### MetricImage

Represents a metric image upload.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `fileName` | String | File name of the metric image |
| `filePath` | String | File path of the metric image |
| `id` | ID! | ID of the metric upload |
| `iid` | ID! | Internal ID of the metric upload |
| `url` | String! | URL of the metric source |

### MetricsDashboard

| Field | Type | Description |
| ----- | ---- | ----------- |
| `annotations` | MetricsDashboardAnnotationConnection | Annotations added to the dashboard |
| `path` | String | Path to a file with the dashboard definition |
| `schemaValidationWarnings` | String! => Array | Dashboard schema validation warnings |

### MetricsDashboardAnnotation

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | String | Description of the annotation |
| `endingAt` | Time | Timestamp marking end of annotated time span |
| `id` | ID! | ID of the annotation |
| `panelId` | String | ID of a dashboard panel to which the annotation should be scoped |
| `startingAt` | Time | Timestamp marking start of annotated time span |

### Milestone

Represents a milestone.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time! | Timestamp of milestone creation |
| `description` | String | Description of the milestone |
| `dueDate` | Time | Timestamp of the milestone due date |
| `groupMilestone` | Boolean! | Indicates if milestone is at group level |
| `id` | ID! | ID of the milestone |
| `projectMilestone` | Boolean! | Indicates if milestone is at project level |
| `report` | TimeboxReport | Historically accurate report about the timebox |
| `startDate` | Time | Timestamp of the milestone start date |
| `state` | MilestoneStateEnum! | State of the milestone |
| `stats` | MilestoneStats | Milestone statistics |
| `subgroupMilestone` | Boolean! | Indicates if milestone is at subgroup level |
| `title` | String! | Title of the milestone |
| `updatedAt` | Time! | Timestamp of last milestone update |
| `webPath` | String! | Web path of the milestone |

### MilestoneStats

Contains statistics about a milestone.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `closedIssuesCount` | Int | Number of closed issues associated with the milestone |
| `totalIssuesCount` | Int | Total number of issues associated with the milestone |

### Namespace

| Field | Type | Description |
| ----- | ---- | ----------- |
| `actualRepositorySizeLimit` | Float | Size limit for repositories in the namespace in bytes |
| `additionalPurchasedStorageSize` | Float | Additional storage purchased for the root namespace in bytes |
| `complianceFrameworks` | ComplianceFrameworkConnection | Compliance frameworks available to projects in this namespace. Available only when feature flag `ff_custom_compliance_frameworks` is enabled. |
| `containsLockedProjects` | Boolean! | Includes at least one project where the repository size exceeds the limit |
| `description` | String | Description of the namespace |
| `descriptionHtml` | String | The GitLab Flavored Markdown rendering of `description` |
| `fullName` | String! | Full name of the namespace |
| `fullPath` | ID! | Full path of the namespace |
| `id` | ID! | ID of the namespace |
| `isTemporaryStorageIncreaseEnabled` | Boolean! | Status of the temporary storage increase |
| `lfsEnabled` | Boolean | Indicates if Large File Storage (LFS) is enabled for namespace |
| `name` | String! | Name of the namespace |
| `packageSettings` | PackageSettings | The package settings for the namespace |
| `path` | String! | Path of the namespace |
| `projects` | ProjectConnection! | Projects within this namespace |
| `repositorySizeExcessProjectCount` | Int! | Number of projects in the root namespace where the repository size exceeds the limit |
| `requestAccessEnabled` | Boolean | Indicates if users can request access to namespace |
| `rootStorageStatistics` | RootStorageStatistics | Aggregated storage statistics of the namespace. Only available for root namespaces |
| `storageSizeLimit` | Float | Total storage limit of the root namespace in bytes |
| `temporaryStorageIncreaseEndsOn` | Time | Date until the temporary storage increase is active |
| `totalRepositorySize` | Float | Total repository size of all projects in the root namespace in bytes |
| `totalRepositorySizeExcess` | Float | Total excess repository size of all projects in the root namespace in bytes |
| `visibility` | String | Visibility of the namespace |

### NamespaceIncreaseStorageTemporarilyPayload

Autogenerated return type of NamespaceIncreaseStorageTemporarily.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `namespace` | Namespace | The namespace after mutation |

### Note

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | User! | User who wrote this note |
| `body` | String! | Content of the note |
| `bodyHtml` | String | The GitLab Flavored Markdown rendering of `note` |
| `confidential` | Boolean | Indicates if this note is confidential |
| `createdAt` | Time! | Timestamp of the note creation |
| `discussion` | Discussion | The discussion this note is a part of |
| `id` | ID! | ID of the note |
| `position` | DiffPosition | The position of this note on a diff |
| `project` | Project | Project associated with the note |
| `resolvable` | Boolean! | Indicates if the object can be resolved |
| `resolved` | Boolean! | Indicates if the object is resolved |
| `resolvedAt` | Time | Timestamp of when the object was resolved |
| `resolvedBy` | User | User who resolved the object |
| `system` | Boolean! | Indicates whether this note was created by the system or by a user |
| `systemNoteIconName` | String | Name of the icon corresponding to a system note |
| `updatedAt` | Time! | Timestamp of the note's last activity |
| `userPermissions` | NotePermissions! | Permissions for the current user on the resource |

### NotePermissions

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminNote` | Boolean! | Indicates the user can perform `admin_note` on this resource |
| `awardEmoji` | Boolean! | Indicates the user can perform `award_emoji` on this resource |
| `createNote` | Boolean! | Indicates the user can perform `create_note` on this resource |
| `readNote` | Boolean! | Indicates the user can perform `read_note` on this resource |
| `repositionNote` | Boolean! | Indicates the user can perform `reposition_note` on this resource |
| `resolveNote` | Boolean! | Indicates the user can perform `resolve_note` on this resource |

### OncallParticipantType

The rotation participant and color palette.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `colorPalette` | String | The color palette to assign to the on-call user. For example "blue". |
| `colorWeight` | String | The color weight to assign to for the on-call user, for example "500". Max 4 chars. For easy identification of the user. |
| `id` | IncidentManagementOncallParticipantID! | ID of the on-call participant. |
| `user` | User! | The user who is participating. |

### OncallRotationCreatePayload

Autogenerated return type of OncallRotationCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `oncallRotation` | IncidentManagementOncallRotation | The on-call rotation. |

### OncallScheduleCreatePayload

Autogenerated return type of OncallScheduleCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `oncallSchedule` | IncidentManagementOncallSchedule | The on-call schedule |

### OncallScheduleDestroyPayload

Autogenerated return type of OncallScheduleDestroy.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `oncallSchedule` | IncidentManagementOncallSchedule | The on-call schedule |

### OncallScheduleUpdatePayload

Autogenerated return type of OncallScheduleUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `oncallSchedule` | IncidentManagementOncallSchedule | The on-call schedule |

### Package

Represents a package.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time! | The created date |
| `id` | ID! | The ID of the package |
| `name` | String! | The name of the package |
| `packageType` | PackageTypeEnum! | The type of the package |
| `updatedAt` | Time! | The update date |
| `version` | String | The version of the package |

### PackageFileRegistry

Represents the Geo sync and verification state of a package file.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time | Timestamp when the PackageFileRegistry was created |
| `id` | ID! | ID of the PackageFileRegistry |
| `lastSyncFailure` | String | Error message during sync of the PackageFileRegistry |
| `lastSyncedAt` | Time | Timestamp of the most recent successful sync of the PackageFileRegistry |
| `packageFileId` | ID! | ID of the PackageFile |
| `retryAt` | Time | Timestamp after which the PackageFileRegistry should be resynced |
| `retryCount` | Int | Number of consecutive failed sync attempts of the PackageFileRegistry |
| `state` | RegistryState | Sync state of the PackageFileRegistry |

### PackageSettings

Namespace-level Package Registry settings.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `mavenDuplicateExceptionRegex` | UntrustedRegexp | When maven_duplicates_allowed is false, you can publish duplicate packages with names that match this regex. Otherwise, this setting has no effect. |
| `mavenDuplicatesAllowed` | Boolean! | Indicates whether duplicate Maven packages are allowed for this namespace. |

### PageInfo

Information about pagination in a connection..

| Field | Type | Description |
| ----- | ---- | ----------- |
| `endCursor` | String | When paginating forwards, the cursor to continue. |
| `hasNextPage` | Boolean! | When paginating forwards, are there more items? |
| `hasPreviousPage` | Boolean! | When paginating backwards, are there more items? |
| `startCursor` | String | When paginating backwards, the cursor to continue. |

### Pipeline

| Field | Type | Description |
| ----- | ---- | ----------- |
| `active` | Boolean! | Indicates if the pipeline is active |
| `beforeSha` | String | Base SHA of the source branch |
| `cancelable` | Boolean! | Specifies if a pipeline can be canceled |
| `committedAt` | Time | Timestamp of the pipeline's commit |
| `configSource` | PipelineConfigSourceEnum | Config source of the pipeline (UNKNOWN_SOURCE, REPOSITORY_SOURCE, AUTO_DEVOPS_SOURCE, WEBIDE_SOURCE, REMOTE_SOURCE, EXTERNAL_PROJECT_SOURCE, BRIDGE_SOURCE, PARAMETER_SOURCE) |
| `coverage` | Float | Coverage percentage |
| `createdAt` | Time! | Timestamp of the pipeline's creation |
| `detailedStatus` | DetailedStatus! | Detailed status of the pipeline |
| `downstream` | PipelineConnection | Pipelines this pipeline will trigger |
| `duration` | Int | Duration of the pipeline in seconds |
| `finishedAt` | Time | Timestamp of the pipeline's completion |
| `id` | ID! | ID of the pipeline |
| `iid` | String! | Internal ID of the pipeline |
| `jobs` | CiJobConnection | Jobs belonging to the pipeline |
| `path` | String | Relative path to the pipeline's page |
| `project` | Project | Project the pipeline belongs to |
| `retryable` | Boolean! | Specifies if a pipeline can be retried |
| `securityReportSummary` | SecurityReportSummary | Vulnerability and scanned resource counts for each security scanner of the pipeline |
| `sha` | String! | SHA of the pipeline's commit |
| `sourceJob` | CiJob | Job where pipeline was triggered from |
| `stages` | CiStageConnection | Stages of the pipeline |
| `startedAt` | Time | Timestamp when the pipeline was started |
| `status` | PipelineStatusEnum! | Status of the pipeline (CREATED, WAITING_FOR_RESOURCE, PREPARING, PENDING, RUNNING, FAILED, SUCCESS, CANCELED, SKIPPED, MANUAL, SCHEDULED) |
| `updatedAt` | Time! | Timestamp of the pipeline's last activity |
| `upstream` | Pipeline | Pipeline that triggered the pipeline |
| `user` | User | Pipeline user |
| `userPermissions` | PipelinePermissions! | Permissions for the current user on the resource |

### PipelineAnalytics

| Field | Type | Description |
| ----- | ---- | ----------- |
| `monthPipelinesLabels` | String! => Array | Labels for the monthly pipeline count |
| `monthPipelinesSuccessful` | Int! => Array | Total monthly successful pipeline count |
| `monthPipelinesTotals` | Int! => Array | Total monthly pipeline count |
| `pipelineTimesLabels` | String! => Array | Pipeline times labels |
| `pipelineTimesValues` | Int! => Array | Pipeline times |
| `weekPipelinesLabels` | String! => Array | Labels for the weekly pipeline count |
| `weekPipelinesSuccessful` | Int! => Array | Total weekly successful pipeline count |
| `weekPipelinesTotals` | Int! => Array | Total weekly pipeline count |
| `yearPipelinesLabels` | String! => Array | Labels for the yearly pipeline count |
| `yearPipelinesSuccessful` | Int! => Array | Total yearly successful pipeline count |
| `yearPipelinesTotals` | Int! => Array | Total yearly pipeline count |

### PipelineCancelPayload

Autogenerated return type of PipelineCancel.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### PipelineDestroyPayload

Autogenerated return type of PipelineDestroy.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### PipelinePermissions

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminPipeline` | Boolean! | Indicates the user can perform `admin_pipeline` on this resource |
| `destroyPipeline` | Boolean! | Indicates the user can perform `destroy_pipeline` on this resource |
| `updatePipeline` | Boolean! | Indicates the user can perform `update_pipeline` on this resource |

### PipelineRetryPayload

Autogenerated return type of PipelineRetry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `pipeline` | Pipeline | The pipeline after mutation. |

### Project

| Field | Type | Description |
| ----- | ---- | ----------- |
| `actualRepositorySizeLimit` | Float | Size limit for the repository in bytes |
| `alertManagementAlert` | AlertManagementAlert | A single Alert Management alert of the project |
| `alertManagementAlertStatusCounts` | AlertManagementAlertStatusCountsType | Counts of alerts by status for the project |
| `alertManagementAlerts` | AlertManagementAlertConnection | Alert Management alerts of the project |
| `alertManagementIntegrations` | AlertManagementIntegrationConnection | Integrations which can receive alerts for the project |
| `allowMergeOnSkippedPipeline` | Boolean | If `only_allow_merge_if_pipeline_succeeds` is true, indicates if merge requests of the project can also be merged with skipped jobs |
| `archived` | Boolean | Indicates the archived status of the project |
| `autocloseReferencedIssues` | Boolean | Indicates if issues referenced by merge requests and commits within the default branch are closed automatically |
| `avatarUrl` | String | URL to avatar image file of the project |
| `board` | Board | A single board of the project |
| `boards` | BoardConnection | Boards of the project |
| `ciCdSettings` | ProjectCiCdSetting | CI/CD settings for the project |
| `clusterAgent` | ClusterAgent | Find a single cluster agent by name |
| `clusterAgents` | ClusterAgentConnection | Cluster agents associated with the project |
| `codeCoverageSummary` | CodeCoverageSummary | Code coverage summary associated with the project |
| `complianceFrameworks` | ComplianceFrameworkConnection | Compliance frameworks associated with the project |
| `containerExpirationPolicy` | ContainerExpirationPolicy | The container expiration policy of the project |
| `containerRegistryEnabled` | Boolean | Indicates if the project stores Docker container images in a container registry |
| `containerRepositories` | ContainerRepositoryConnection | Container repositories of the project |
| `containerRepositoriesCount` | Int! | Number of container repositories in the project |
| `createdAt` | Time | Timestamp of the project creation |
| `dastScannerProfiles` | DastScannerProfileConnection | The DAST scanner profiles associated with the project |
| `dastSiteProfile` | DastSiteProfile | DAST Site Profile associated with the project |
| `dastSiteProfiles` | DastSiteProfileConnection | DAST Site Profiles associated with the project |
| `dastSiteValidations` | DastSiteValidationConnection | DAST Site Validations associated with the project. Will always return no nodes if `security_on_demand_scans_site_validation` is disabled |
| `description` | String | Short description of the project |
| `descriptionHtml` | String | The GitLab Flavored Markdown rendering of `description` |
| `environment` | Environment | A single environment of the project |
| `environments` | EnvironmentConnection | Environments of the project |
| `forksCount` | Int! | Number of times the project has been forked |
| `fullPath` | ID! | Full path of the project |
| `grafanaIntegration` | GrafanaIntegration | Grafana integration details for the project |
| `group` | Group | Group of the project |
| `httpUrlToRepo` | String | URL to connect to the project via HTTPS |
| `id` | ID! | ID of the project |
| `importStatus` | String | Status of import background job of the project |
| `incidentManagementOncallSchedules` | IncidentManagementOncallScheduleConnection | Incident Management On-call schedules of the project |
| `issue` | Issue | A single issue of the project |
| `issueStatusCounts` | IssueStatusCountsType | Counts of issues by status for the project |
| `issues` | IssueConnection | Issues of the project |
| `issuesEnabled` | Boolean | Indicates if Issues are enabled for the current user |
| `iterations` | IterationConnection | Find iterations |
| `jiraImportStatus` | String | Status of Jira import background job of the project |
| `jiraImports` | JiraImportConnection | Jira imports into the project |
| `jobsEnabled` | Boolean | Indicates if CI/CD pipeline jobs are enabled for the current user |
| `label` | Label | A label available on this project |
| `labels` | LabelConnection | Labels available on this project |
| `lastActivityAt` | Time | Timestamp of the project last activity |
| `lfsEnabled` | Boolean | Indicates if the project has Large File Storage (LFS) enabled |
| `mergeRequest` | MergeRequest | A single merge request of the project |
| `mergeRequests` | MergeRequestConnection | Merge requests of the project |
| `mergeRequestsEnabled` | Boolean | Indicates if Merge Requests are enabled for the current user |
| `mergeRequestsFfOnlyEnabled` | Boolean | Indicates if no merge commits should be created and all merges should instead be fast-forwarded, which means that merging is only allowed if the branch could be fast-forwarded. |
| `milestones` | MilestoneConnection | Milestones of the project |
| `name` | String! | Name of the project (without namespace) |
| `nameWithNamespace` | String! | Full name of the project with its namespace |
| `namespace` | Namespace | Namespace of the project |
| `onlyAllowMergeIfAllDiscussionsAreResolved` | Boolean | Indicates if merge requests of the project can only be merged when all the discussions are resolved |
| `onlyAllowMergeIfPipelineSucceeds` | Boolean | Indicates if merge requests of the project can only be merged with successful jobs |
| `openIssuesCount` | Int | Number of open issues for the project |
| `packages` | PackageConnection | Packages of the project |
| `path` | String! | Path of the project |
| `pipeline` | Pipeline | Build pipeline of the project |
| `pipelineAnalytics` | PipelineAnalytics | Pipeline analytics |
| `pipelines` | PipelineConnection | Build pipelines of the project |
| `printingMergeRequestLinkEnabled` | Boolean | Indicates if a link to create or view a merge request should display after a push to Git repositories of the project from the command line |
| `projectMembers` | MemberInterfaceConnection | Members of the project |
| `publicJobs` | Boolean | Indicates if there is public access to pipelines and job details of the project, including output logs and artifacts |
| `release` | Release | A single release of the project |
| `releases` | ReleaseConnection | Releases of the project |
| `removeSourceBranchAfterMerge` | Boolean | Indicates if `Delete source branch` option should be enabled by default for all new merge requests of the project |
| `repository` | Repository | Git repository of the project |
| `repositorySizeExcess` | Float | Size of repository that exceeds the limit in bytes |
| `requestAccessEnabled` | Boolean | Indicates if users can request member access to the project |
| `requirement` | Requirement | Find a single requirement |
| `requirementStatesCount` | RequirementStatesCount | Number of requirements for the project by their state |
| `requirements` | RequirementConnection | Find requirements |
| `sastCiConfiguration` | SastCiConfiguration | SAST CI configuration for the project |
| `securityDashboardPath` | String | Path to project's security dashboard |
| `securityScanners` | SecurityScanners | Information about security analyzers used in the project |
| `sentryDetailedError` | SentryDetailedError | Detailed version of a Sentry error on the project |
| `sentryErrors` | SentryErrorCollection | Paginated collection of Sentry errors on the project |
| `serviceDeskAddress` | String | E-mail address of the service desk. |
| `serviceDeskEnabled` | Boolean | Indicates if the project has service desk enabled. |
| `services` | ServiceConnection | Project services |
| `sharedRunnersEnabled` | Boolean | Indicates if shared runners are enabled for the project |
| `snippets` | SnippetConnection | Snippets of the project |
| `snippetsEnabled` | Boolean | Indicates if Snippets are enabled for the current user |
| `squashReadOnly` | Boolean! | Indicates if squash readonly is enabled |
| `sshUrlToRepo` | String | URL to connect to the project via SSH |
| `starCount` | Int! | Number of times the project has been starred |
| `statistics` | ProjectStatistics | Statistics of the project |
| `suggestionCommitMessage` | String | The commit message used to apply merge request suggestions |
| `tagList` | String | List of project topics (not Git tags) |
| `terraformStates` | TerraformStateConnection | Terraform states associated with the project |
| `userPermissions` | ProjectPermissions! | Permissions for the current user on the resource |
| `visibility` | String | Visibility of the project |
| `vulnerabilities` | VulnerabilityConnection | Vulnerabilities reported on the project |
| `vulnerabilitiesCountByDay` | VulnerabilitiesCountByDayConnection | Number of vulnerabilities per day for the project |
| `vulnerabilityScanners` | VulnerabilityScannerConnection | Vulnerability scanners reported on the project vulnerabilties |
| `vulnerabilitySeveritiesCount` | VulnerabilitySeveritiesCount | Counts for each vulnerability severity in the project |
| `webUrl` | String | Web URL of the project |
| `wikiEnabled` | Boolean | Indicates if Wikis are enabled for the current user |

### ProjectCiCdSetting

| Field | Type | Description |
| ----- | ---- | ----------- |
| `mergePipelinesEnabled` | Boolean | Whether merge pipelines are enabled. |
| `mergeTrainsEnabled` | Boolean | Whether merge trains are enabled. |
| `project` | Project | Project the CI/CD settings belong to. |

### ProjectMember

Represents a Project Membership.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `accessLevel` | AccessLevel | GitLab::Access level |
| `createdAt` | Time | Date and time the membership was created |
| `createdBy` | User | User that authorized membership |
| `expiresAt` | Time | Date and time the membership expires |
| `id` | ID! | ID of the member |
| `project` | Project | Project that User is a member of |
| `updatedAt` | Time | Date and time the membership was last updated |
| `user` | User! | User that is associated with the member object |
| `userPermissions` | ProjectPermissions! | Permissions for the current user on the resource |

### ProjectPermissions

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminOperations` | Boolean! | Indicates the user can perform `admin_operations` on this resource |
| `adminProject` | Boolean! | Indicates the user can perform `admin_project` on this resource |
| `adminRemoteMirror` | Boolean! | Indicates the user can perform `admin_remote_mirror` on this resource |
| `adminWiki` | Boolean! | Indicates the user can perform `admin_wiki` on this resource |
| `archiveProject` | Boolean! | Indicates the user can perform `archive_project` on this resource |
| `changeNamespace` | Boolean! | Indicates the user can perform `change_namespace` on this resource |
| `changeVisibilityLevel` | Boolean! | Indicates the user can perform `change_visibility_level` on this resource |
| `createDeployment` | Boolean! | Indicates the user can perform `create_deployment` on this resource |
| `createDesign` | Boolean! | Indicates the user can perform `create_design` on this resource |
| `createIssue` | Boolean! | Indicates the user can perform `create_issue` on this resource |
| `createLabel` | Boolean! | Indicates the user can perform `create_label` on this resource |
| `createMergeRequestFrom` | Boolean! | Indicates the user can perform `create_merge_request_from` on this resource |
| `createMergeRequestIn` | Boolean! | Indicates the user can perform `create_merge_request_in` on this resource |
| `createPages` | Boolean! | Indicates the user can perform `create_pages` on this resource |
| `createPipeline` | Boolean! | Indicates the user can perform `create_pipeline` on this resource |
| `createPipelineSchedule` | Boolean! | Indicates the user can perform `create_pipeline_schedule` on this resource |
| `createSnippet` | Boolean! | Indicates the user can perform `create_snippet` on this resource |
| `createWiki` | Boolean! | Indicates the user can perform `create_wiki` on this resource |
| `destroyDesign` | Boolean! | Indicates the user can perform `destroy_design` on this resource |
| `destroyPages` | Boolean! | Indicates the user can perform `destroy_pages` on this resource |
| `destroyWiki` | Boolean! | Indicates the user can perform `destroy_wiki` on this resource |
| `downloadCode` | Boolean! | Indicates the user can perform `download_code` on this resource |
| `downloadWikiCode` | Boolean! | Indicates the user can perform `download_wiki_code` on this resource |
| `forkProject` | Boolean! | Indicates the user can perform `fork_project` on this resource |
| `pushCode` | Boolean! | Indicates the user can perform `push_code` on this resource |
| `pushToDeleteProtectedBranch` | Boolean! | Indicates the user can perform `push_to_delete_protected_branch` on this resource |
| `readCommitStatus` | Boolean! | Indicates the user can perform `read_commit_status` on this resource |
| `readCycleAnalytics` | Boolean! | Indicates the user can perform `read_cycle_analytics` on this resource |
| `readDesign` | Boolean! | Indicates the user can perform `read_design` on this resource |
| `readMergeRequest` | Boolean! | Indicates the user can perform `read_merge_request` on this resource |
| `readPagesContent` | Boolean! | Indicates the user can perform `read_pages_content` on this resource |
| `readProject` | Boolean! | Indicates the user can perform `read_project` on this resource |
| `readProjectMember` | Boolean! | Indicates the user can perform `read_project_member` on this resource |
| `readWiki` | Boolean! | Indicates the user can perform `read_wiki` on this resource |
| `removeForkProject` | Boolean! | Indicates the user can perform `remove_fork_project` on this resource |
| `removePages` | Boolean! | Indicates the user can perform `remove_pages` on this resource |
| `removeProject` | Boolean! | Indicates the user can perform `remove_project` on this resource |
| `renameProject` | Boolean! | Indicates the user can perform `rename_project` on this resource |
| `requestAccess` | Boolean! | Indicates the user can perform `request_access` on this resource |
| `updatePages` | Boolean! | Indicates the user can perform `update_pages` on this resource |
| `updateWiki` | Boolean! | Indicates the user can perform `update_wiki` on this resource |
| `uploadFile` | Boolean! | Indicates the user can perform `upload_file` on this resource |

### ProjectStatistics

| Field | Type | Description |
| ----- | ---- | ----------- |
| `buildArtifactsSize` | Float! | Build artifacts size of the project in bytes |
| `commitCount` | Float! | Commit count of the project |
| `lfsObjectsSize` | Float! | Large File Storage (LFS) object size of the project in bytes |
| `packagesSize` | Float! | Packages size of the project in bytes |
| `repositorySize` | Float! | Repository size of the project in bytes |
| `snippetsSize` | Float | Snippets size of the project in bytes |
| `storageSize` | Float! | Storage size of the project in bytes |
| `uploadsSize` | Float | Uploads size of the project in bytes |
| `wikiSize` | Float | Wiki size of the project in bytes |

### PrometheusAlert

The alert condition for Prometheus.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `humanizedText` | String! | The human-readable text of the alert condition |
| `id` | ID! | ID of the alert condition |

### PrometheusIntegrationCreatePayload

Autogenerated return type of PrometheusIntegrationCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `integration` | AlertManagementPrometheusIntegration | The newly created integration. |

### PrometheusIntegrationResetTokenPayload

Autogenerated return type of PrometheusIntegrationResetToken.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `integration` | AlertManagementPrometheusIntegration | The newly created integration. |

### PrometheusIntegrationUpdatePayload

Autogenerated return type of PrometheusIntegrationUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `integration` | AlertManagementPrometheusIntegration | The newly created integration. |

### PromoteToEpicPayload

Autogenerated return type of PromoteToEpic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `epic` | Epic | The epic after issue promotion |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### Release

Represents a release.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `assets` | ReleaseAssets | Assets of the release |
| `author` | User | User that created the release |
| `commit` | Commit | The commit associated with the release |
| `createdAt` | Time | Timestamp of when the release was created |
| `description` | String | Description (also known as "release notes") of the release |
| `descriptionHtml` | String | The GitLab Flavored Markdown rendering of `description` |
| `evidences` | ReleaseEvidenceConnection | Evidence for the release |
| `links` | ReleaseLinks | Links of the release |
| `milestones` | MilestoneConnection | Milestones associated to the release |
| `name` | String | Name of the release |
| `releasedAt` | Time | Timestamp of when the release was released |
| `tagName` | String | Name of the tag associated with the release |
| `tagPath` | String | Relative web path to the tag associated with the release |
| `upcomingRelease` | Boolean | Indicates the release is an upcoming release |

### ReleaseAssetLink

Represents an asset link associated with a release.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `directAssetUrl` | String | Direct asset URL of the link |
| `external` | Boolean | Indicates the link points to an external resource |
| `id` | ID! | ID of the link |
| `linkType` | ReleaseAssetLinkType | Type of the link: `other`, `runbook`, `image`, `package`; defaults to `other` |
| `name` | String | Name of the link |
| `url` | String | URL of the link |

### ReleaseAssets

A container for all assets associated with a release.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | Int | Number of assets of the release |
| `links` | ReleaseAssetLinkConnection | Asset links of the release |
| `sources` | ReleaseSourceConnection | Sources of the release |

### ReleaseCreatePayload

Autogenerated return type of ReleaseCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `release` | Release | The release after mutation. |

### ReleaseDeletePayload

Autogenerated return type of ReleaseDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `release` | Release | The deleted release. |

### ReleaseEvidence

Evidence for a release.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `collectedAt` | Time | Timestamp when the evidence was collected |
| `filepath` | String | URL from where the evidence can be downloaded |
| `id` | ID! | ID of the evidence |
| `sha` | String | SHA1 ID of the evidence hash |

### ReleaseLinks

| Field | Type | Description |
| ----- | ---- | ----------- |
| `closedIssuesUrl` | String | HTTP URL of the issues page, filtered by this release and `state=closed` |
| `closedMergeRequestsUrl` | String | HTTP URL of the merge request page , filtered by this release and `state=closed` |
| `editUrl` | String | HTTP URL of the release's edit page |
| `mergedMergeRequestsUrl` | String | HTTP URL of the merge request page , filtered by this release and `state=merged` |
| `openedIssuesUrl` | String | HTTP URL of the issues page, filtered by this release and `state=open` |
| `openedMergeRequestsUrl` | String | HTTP URL of the merge request page, filtered by this release and `state=open` |
| `selfUrl` | String | HTTP URL of the release |

### ReleaseSource

Represents the source code attached to a release in a particular format.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `format` | String | Format of the source |
| `url` | String | Download URL of the source |

### ReleaseUpdatePayload

Autogenerated return type of ReleaseUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `release` | Release | The release after mutation. |

### RemoveAwardEmojiPayload

Autogenerated return type of RemoveAwardEmoji.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `awardEmoji` | AwardEmoji | The award emoji after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### RemoveProjectFromSecurityDashboardPayload

Autogenerated return type of RemoveProjectFromSecurityDashboard.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### RepositionImageDiffNotePayload

Autogenerated return type of RepositionImageDiffNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `note` | Note | The note after mutation. |

### Repository

| Field | Type | Description |
| ----- | ---- | ----------- |
| `empty` | Boolean! | Indicates repository has no visible content |
| `exists` | Boolean! | Indicates a corresponding Git repository exists on disk |
| `rootRef` | String | Default branch of the repository |
| `tree` | Tree | Tree of the repository |

### Requirement

Represents a requirement.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | User! | Author of the requirement |
| `createdAt` | Time! | Timestamp of when the requirement was created |
| `description` | String | Description of the requirement |
| `descriptionHtml` | String | The GitLab Flavored Markdown rendering of `description` |
| `id` | ID! | ID of the requirement |
| `iid` | ID! | Internal ID of the requirement |
| `lastTestReportManuallyCreated` | Boolean | Indicates if latest test report was created by user |
| `lastTestReportState` | TestReportState | Latest requirement test report state |
| `project` | Project! | Project to which the requirement belongs |
| `state` | RequirementState! | State of the requirement |
| `testReports` | TestReportConnection | Test reports of the requirement |
| `title` | String | Title of the requirement |
| `titleHtml` | String | The GitLab Flavored Markdown rendering of `title` |
| `updatedAt` | Time! | Timestamp of when the requirement was last updated |
| `userPermissions` | RequirementPermissions! | Permissions for the current user on the resource |

### RequirementPermissions

Check permissions for the current user on a requirement.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminRequirement` | Boolean! | Indicates the user can perform `admin_requirement` on this resource |
| `createRequirement` | Boolean! | Indicates the user can perform `create_requirement` on this resource |
| `destroyRequirement` | Boolean! | Indicates the user can perform `destroy_requirement` on this resource |
| `readRequirement` | Boolean! | Indicates the user can perform `read_requirement` on this resource |
| `updateRequirement` | Boolean! | Indicates the user can perform `update_requirement` on this resource |

### RequirementStatesCount

Counts of requirements by their state.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `archived` | Int | Number of archived requirements |
| `opened` | Int | Number of opened requirements |

### RevertVulnerabilityToDetectedPayload

Autogenerated return type of RevertVulnerabilityToDetected.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `vulnerability` | Vulnerability | The vulnerability after revert |

### RootStorageStatistics

| Field | Type | Description |
| ----- | ---- | ----------- |
| `buildArtifactsSize` | Float! | The CI artifacts size in bytes |
| `lfsObjectsSize` | Float! | The LFS objects size in bytes |
| `packagesSize` | Float! | The packages size in bytes |
| `pipelineArtifactsSize` | Float! | The CI pipeline artifacts size in bytes |
| `repositorySize` | Float! | The Git repository size in bytes |
| `snippetsSize` | Float! | The snippets size in bytes |
| `storageSize` | Float! | The total storage in bytes |
| `uploadsSize` | Float! | The uploads size in bytes |
| `wikiSize` | Float! | The wiki size in bytes |

### RunDASTScanPayload

Autogenerated return type of RunDASTScan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `pipelineUrl` | String | URL of the pipeline that was created. |

### RunnerArchitecture

| Field | Type | Description |
| ----- | ---- | ----------- |
| `downloadLocation` | String! | Download location for the runner for the platform architecture |
| `name` | String! | Name of the runner platform architecture |

### RunnerPlatform

| Field | Type | Description |
| ----- | ---- | ----------- |
| `architectures` | RunnerArchitectureConnection | Runner architectures supported for the platform |
| `humanReadableName` | String! | Human readable name of the runner platform |
| `name` | String! | Name slug of the runner platform |

### RunnerSetup

| Field | Type | Description |
| ----- | ---- | ----------- |
| `installInstructions` | String! | Instructions for installing the runner on the specified architecture |
| `registerInstructions` | String | Instructions for registering the runner |

### SastCiConfiguration

Represents a CI configuration of SAST.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `analyzers` | SastCiConfigurationAnalyzersEntityConnection | List of analyzers entities attached to SAST configuration. |
| `global` | SastCiConfigurationEntityConnection | List of global entities related to SAST configuration. |
| `pipeline` | SastCiConfigurationEntityConnection | List of pipeline entities related to SAST configuration. |

### SastCiConfigurationAnalyzersEntity

Represents an analyzer entity in SAST CI configuration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | String | Analyzer description that is displayed on the form |
| `enabled` | Boolean | Indicates whether an analyzer is enabled |
| `label` | String | Analyzer label used in the config UI |
| `name` | String | Name of the analyzer |
| `variables` | SastCiConfigurationEntityConnection | List of supported variables |

### SastCiConfigurationEntity

Represents an entity in SAST CI configuration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `defaultValue` | String | Default value that is used if value is empty. |
| `description` | String | Entity description that is displayed on the form. |
| `field` | String | CI keyword of entity. |
| `label` | String | Label for entity used in the form. |
| `options` | SastCiConfigurationOptionsEntityConnection | Different possible values of the field. |
| `size` | SastUiComponentSize | Size of the UI component. |
| `type` | String | Type of the field value. |
| `value` | String | Current value of the entity. |

### SastCiConfigurationOptionsEntity

Represents an entity for options in SAST CI configuration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `label` | String | Label of option entity. |
| `value` | String | Value of option entity. |

### ScannedResource

Represents a resource scanned by a security scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `requestMethod` | String | The HTTP request method used to access the URL |
| `url` | String | The URL scanned by the scanner |

### SecurityReportSummary

Represents summary of a security report.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `apiFuzzing` | SecurityReportSummarySection | Aggregated counts for the api_fuzzing scan |
| `containerScanning` | SecurityReportSummarySection | Aggregated counts for the container_scanning scan |
| `coverageFuzzing` | SecurityReportSummarySection | Aggregated counts for the coverage_fuzzing scan |
| `dast` | SecurityReportSummarySection | Aggregated counts for the dast scan |
| `dependencyScanning` | SecurityReportSummarySection | Aggregated counts for the dependency_scanning scan |
| `sast` | SecurityReportSummarySection | Aggregated counts for the sast scan |
| `secretDetection` | SecurityReportSummarySection | Aggregated counts for the secret_detection scan |

### SecurityReportSummarySection

Represents a section of a summary of a security report.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `scannedResources` | ScannedResourceConnection | A list of the first 20 scanned resources |
| `scannedResourcesCount` | Int | Total number of scanned resources |
| `scannedResourcesCsvPath` | String | Path to download all the scanned resources in CSV format |
| `vulnerabilitiesCount` | Int | Total number of vulnerabilities |

### SecurityScanners

Represents a list of security scanners.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `available` | SecurityScannerType! => Array | List of analyzers which are available for the project. |
| `enabled` | SecurityScannerType! => Array | List of analyzers which are enabled for the project. |
| `pipelineRun` | SecurityScannerType! => Array | List of analyzers which ran successfully in the latest pipeline. |

### SentryDetailedError

A Sentry error.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | Int! | Count of occurrences |
| `culprit` | String! | Culprit of the error |
| `externalBaseUrl` | String! | External Base URL of the Sentry Instance |
| `externalUrl` | String! | External URL of the error |
| `firstReleaseLastCommit` | String | Commit the error was first seen |
| `firstReleaseShortVersion` | String | Release short version the error was first seen |
| `firstReleaseVersion` | String | Release version the error was first seen |
| `firstSeen` | Time! | Timestamp when the error was first seen |
| `frequency` | SentryErrorFrequency! => Array | Last 24hr stats of the error |
| `gitlabCommit` | String | GitLab commit SHA attributed to the Error based on the release version |
| `gitlabCommitPath` | String | Path to the GitLab page for the GitLab commit attributed to the error |
| `gitlabIssuePath` | String | URL of GitLab Issue |
| `id` | ID! | ID (global ID) of the error |
| `lastReleaseLastCommit` | String | Commit the error was last seen |
| `lastReleaseShortVersion` | String | Release short version the error was last seen |
| `lastReleaseVersion` | String | Release version the error was last seen |
| `lastSeen` | Time! | Timestamp when the error was last seen |
| `message` | String | Sentry metadata message of the error |
| `sentryId` | String! | ID (Sentry ID) of the error |
| `sentryProjectId` | ID! | ID of the project (Sentry project) |
| `sentryProjectName` | String! | Name of the project affected by the error |
| `sentryProjectSlug` | String! | Slug of the project affected by the error |
| `shortId` | String! | Short ID (Sentry ID) of the error |
| `status` | SentryErrorStatus! | Status of the error |
| `tags` | SentryErrorTags! | Tags associated with the Sentry Error |
| `title` | String! | Title of the error |
| `type` | String! | Type of the error |
| `userCount` | Int! | Count of users affected by the error |

### SentryError

A Sentry error. A simplified version of SentryDetailedError.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | Int! | Count of occurrences |
| `culprit` | String! | Culprit of the error |
| `externalUrl` | String! | External URL of the error |
| `firstSeen` | Time! | Timestamp when the error was first seen |
| `frequency` | SentryErrorFrequency! => Array | Last 24hr stats of the error |
| `id` | ID! | ID (global ID) of the error |
| `lastSeen` | Time! | Timestamp when the error was last seen |
| `message` | String | Sentry metadata message of the error |
| `sentryId` | String! | ID (Sentry ID) of the error |
| `sentryProjectId` | ID! | ID of the project (Sentry project) |
| `sentryProjectName` | String! | Name of the project affected by the error |
| `sentryProjectSlug` | String! | Slug of the project affected by the error |
| `shortId` | String! | Short ID (Sentry ID) of the error |
| `status` | SentryErrorStatus! | Status of the error |
| `title` | String! | Title of the error |
| `type` | String! | Type of the error |
| `userCount` | Int! | Count of users affected by the error |

### SentryErrorCollection

An object containing a collection of Sentry errors, and a detailed error.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `detailedError` | SentryDetailedError | Detailed version of a Sentry error on the project |
| `errorStackTrace` | SentryErrorStackTrace | Stack Trace of Sentry Error |
| `errors` | SentryErrorConnection | Collection of Sentry Errors |
| `externalUrl` | String | External URL for Sentry |

### SentryErrorFrequency

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | Int! | Count of errors received since the previously recorded time |
| `time` | Time! | Time the error frequency stats were recorded |

### SentryErrorStackTrace

An object containing a stack trace entry for a Sentry error.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `dateReceived` | String! | Time the stack trace was received by Sentry |
| `issueId` | String! | ID of the Sentry error |
| `stackTraceEntries` | SentryErrorStackTraceEntry! => Array | Stack trace entries for the Sentry error |

### SentryErrorStackTraceContext

An object context for a Sentry error stack trace.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `code` | String! | Code number of the context |
| `line` | Int! | Line number of the context |

### SentryErrorStackTraceEntry

An object containing a stack trace entry for a Sentry error.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `col` | String | Function in which the Sentry error occurred |
| `fileName` | String | File in which the Sentry error occurred |
| `function` | String | Function in which the Sentry error occurred |
| `line` | String | Function in which the Sentry error occurred |
| `traceContext` | SentryErrorStackTraceContext! => Array | Context of the Sentry error |

### SentryErrorTags

State of a Sentry error.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `level` | String | Severity level of the Sentry Error |
| `logger` | String | Logger of the Sentry Error |

### Snippet

Represents a snippet entry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | User | The owner of the snippet |
| `blob` **{warning-solid}** | SnippetBlob! | **Deprecated:** Use `blobs`. Deprecated in 13.3. |
| `blobs` | SnippetBlobConnection | Snippet blobs |
| `createdAt` | Time! | Timestamp this snippet was created |
| `description` | String | Description of the snippet |
| `descriptionHtml` | String | The GitLab Flavored Markdown rendering of `description` |
| `discussions` | DiscussionConnection! | All discussions on this noteable |
| `fileName` | String | File Name of the snippet |
| `httpUrlToRepo` | String | HTTP URL to the snippet repository |
| `id` | SnippetID! | ID of the snippet |
| `notes` | NoteConnection! | All notes on this noteable |
| `project` | Project | The project the snippet is associated with |
| `rawUrl` | String! | Raw URL of the snippet |
| `sshUrlToRepo` | String | SSH URL to the snippet repository |
| `title` | String! | Title of the snippet |
| `updatedAt` | Time! | Timestamp this snippet was updated |
| `userPermissions` | SnippetPermissions! | Permissions for the current user on the resource |
| `visibilityLevel` | VisibilityLevelsEnum! | Visibility Level of the snippet |
| `webUrl` | String! | Web URL of the snippet |

### SnippetBlob

Represents the snippet blob.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `binary` | Boolean! | Shows whether the blob is binary |
| `externalStorage` | String | Blob external storage |
| `mode` | String | Blob mode |
| `name` | String | Blob name |
| `path` | String | Blob path |
| `plainData` | String | Blob plain highlighted data |
| `rawPath` | String! | Blob raw content endpoint path |
| `renderedAsText` | Boolean! | Shows whether the blob is rendered as text |
| `richData` | String | Blob highlighted data |
| `richViewer` | SnippetBlobViewer | Blob content rich viewer |
| `simpleViewer` | SnippetBlobViewer! | Blob content simple viewer |
| `size` | Int! | Blob size |

### SnippetBlobViewer

Represents how the blob content should be displayed.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `collapsed` | Boolean! | Shows whether the blob should be displayed collapsed |
| `fileType` | String! | Content file type |
| `loadAsync` | Boolean! | Shows whether the blob content is loaded async |
| `loadingPartialName` | String! | Loading partial name |
| `renderError` | String | Error rendering the blob content |
| `tooLarge` | Boolean! | Shows whether the blob too large to be displayed |
| `type` | BlobViewersType! | Type of blob viewer |

### SnippetPermissions

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminSnippet` | Boolean! | Indicates the user can perform `admin_snippet` on this resource |
| `awardEmoji` | Boolean! | Indicates the user can perform `award_emoji` on this resource |
| `createNote` | Boolean! | Indicates the user can perform `create_note` on this resource |
| `readSnippet` | Boolean! | Indicates the user can perform `read_snippet` on this resource |
| `reportSnippet` | Boolean! | Indicates the user can perform `report_snippet` on this resource |
| `updateSnippet` | Boolean! | Indicates the user can perform `update_snippet` on this resource |

### SnippetRepositoryRegistry

Represents the Geo sync and verification state of a snippet repository.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time | Timestamp when the SnippetRepositoryRegistry was created |
| `id` | ID! | ID of the SnippetRepositoryRegistry |
| `lastSyncFailure` | String | Error message during sync of the SnippetRepositoryRegistry |
| `lastSyncedAt` | Time | Timestamp of the most recent successful sync of the SnippetRepositoryRegistry |
| `retryAt` | Time | Timestamp after which the SnippetRepositoryRegistry should be resynced |
| `retryCount` | Int | Number of consecutive failed sync attempts of the SnippetRepositoryRegistry |
| `snippetRepositoryId` | ID! | ID of the Snippet Repository |
| `state` | RegistryState | Sync state of the SnippetRepositoryRegistry |

### StatusAction

| Field | Type | Description |
| ----- | ---- | ----------- |
| `buttonTitle` | String | Title for the button, for example: Retry this job |
| `icon` | String | Icon used in the action button |
| `method` | String | Method for the action, for example: :post |
| `path` | String | Path for the action |
| `title` | String | Title for the action, for example: Retry |

### Submodule

| Field | Type | Description |
| ----- | ---- | ----------- |
| `flatPath` | String! | Flat path of the entry |
| `id` | ID! | ID of the entry |
| `name` | String! | Name of the entry |
| `path` | String! | Path of the entry |
| `sha` | String! | Last commit sha for the entry |
| `treeUrl` | String | Tree URL for the sub-module |
| `type` | EntryType! | Type of tree entry |
| `webUrl` | String | Web URL for the sub-module |

### TaskCompletionStatus

Completion status of tasks.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `completedCount` | Int! | Number of completed tasks |
| `count` | Int! | Number of total tasks |

### TerraformState

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time! | Timestamp the Terraform state was created |
| `id` | ID! | ID of the Terraform state |
| `latestVersion` | TerraformStateVersion | The latest version of the Terraform state |
| `lockedAt` | Time | Timestamp the Terraform state was locked |
| `lockedByUser` | User | The user currently holding a lock on the Terraform state |
| `name` | String! | Name of the Terraform state |
| `updatedAt` | Time! | Timestamp the Terraform state was updated |

### TerraformStateDeletePayload

Autogenerated return type of TerraformStateDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### TerraformStateLockPayload

Autogenerated return type of TerraformStateLock.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### TerraformStateUnlockPayload

Autogenerated return type of TerraformStateUnlock.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### TerraformStateVersion

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time! | Timestamp the version was created |
| `createdByUser` | User | The user that created this version |
| `downloadPath` | String | URL for downloading the version's JSON file |
| `id` | ID! | ID of the Terraform state version |
| `job` | CiJob | The job that created this version |
| `serial` | Int | Serial number of the version |
| `updatedAt` | Time! | Timestamp the version was updated |

### TerraformStateVersionRegistry

Represents the Geo sync and verification state of a terraform state version.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | Time | Timestamp when the TerraformStateVersionRegistry was created |
| `id` | ID! | ID of the TerraformStateVersionRegistry |
| `lastSyncFailure` | String | Error message during sync of the TerraformStateVersionRegistry |
| `lastSyncedAt` | Time | Timestamp of the most recent successful sync of the TerraformStateVersionRegistry |
| `retryAt` | Time | Timestamp after which the TerraformStateVersionRegistry should be resynced |
| `retryCount` | Int | Number of consecutive failed sync attempts of the TerraformStateVersionRegistry |
| `state` | RegistryState | Sync state of the TerraformStateVersionRegistry |
| `terraformStateVersionId` | ID! | ID of the terraform state version |

### TestReport

Represents a requirement test report.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | User | Author of the test report |
| `createdAt` | Time! | Timestamp of when the test report was created |
| `id` | ID! | ID of the test report |
| `state` | TestReportState! | State of the test report |

### TimeReportStats

Represents the time report stats for timeboxes.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `complete` | TimeboxMetrics | Completed issues metrics |
| `incomplete` | TimeboxMetrics | Incomplete issues metrics |
| `total` | TimeboxMetrics | Total issues metrics |

### TimeboxMetrics

Represents measured stats metrics for timeboxes.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | Int! | The count metric |
| `weight` | Int! | The weight metric |

### TimeboxReport

Represents a historically accurate report about the timebox.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `burnupTimeSeries` | BurnupChartDailyTotals! => Array | Daily scope and completed totals for burnup charts |
| `stats` | TimeReportStats | Represents the time report stats for the timebox |

### Timelog

| Field | Type | Description |
| ----- | ---- | ----------- |
| `issue` | Issue | The issue that logged time was added to |
| `note` | Note | The note where the quick action to add the logged time was executed |
| `spentAt` | Time | Timestamp of when the time tracked was spent at |
| `timeSpent` | Int! | The time spent displayed in seconds |
| `user` | User! | The user that logged the time |

### Todo

Representing a todo entry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `action` | TodoActionEnum! | Action of the todo |
| `author` | User! | The author of this todo |
| `body` | String! | Body of the todo |
| `createdAt` | Time! | Timestamp this todo was created |
| `group` | Group | Group this todo is associated with |
| `id` | ID! | ID of the todo |
| `project` | Project | The project this todo is associated with |
| `state` | TodoStateEnum! | State of the todo |
| `targetType` | TodoTargetEnum! | Target type of the todo |

### TodoCreatePayload

Autogenerated return type of TodoCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `todo` | Todo | The to-do created. |

### TodoMarkDonePayload

Autogenerated return type of TodoMarkDone.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `todo` | Todo! | The requested todo. |

### TodoRestoreManyPayload

Autogenerated return type of TodoRestoreMany.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `todos` | Todo! => Array | Updated todos. |
| `updatedIds` **{warning-solid}** | TodoID! => Array | **Deprecated:** Use todos. Deprecated in 13.2. |

### TodoRestorePayload

Autogenerated return type of TodoRestore.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `todo` | Todo! | The requested todo. |

### TodosMarkAllDonePayload

Autogenerated return type of TodosMarkAllDone.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `todos` | Todo! => Array | Updated todos. |
| `updatedIds` **{warning-solid}** | TodoID! => Array | **Deprecated:** Use todos. Deprecated in 13.2. |

### ToggleAwardEmojiPayload

Autogenerated return type of ToggleAwardEmoji.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `awardEmoji` | AwardEmoji | The award emoji after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `toggledOn` | Boolean! | Indicates the status of the emoji. True if the toggle awarded the emoji, and false if the toggle removed the emoji. |

### Tree

| Field | Type | Description |
| ----- | ---- | ----------- |
| `blobs` | BlobConnection! | Blobs of the tree |
| `lastCommit` | Commit | Last commit for the tree |
| `submodules` | SubmoduleConnection! | Sub-modules of the tree |
| `trees` | TreeEntryConnection! | Trees of the tree |

### TreeEntry

Represents a directory.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `flatPath` | String! | Flat path of the entry |
| `id` | ID! | ID of the entry |
| `name` | String! | Name of the entry |
| `path` | String! | Path of the entry |
| `sha` | String! | Last commit sha for the entry |
| `type` | EntryType! | Type of tree entry |
| `webPath` | String | Web path for the tree entry (directory) |
| `webUrl` | String | Web URL for the tree entry (directory) |

### UpdateAlertStatusPayload

Autogenerated return type of UpdateAlertStatus.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `alert` | AlertManagementAlert | The alert after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue created after mutation. |
| `todo` | Todo | The todo after mutation. |

### UpdateBoardEpicUserPreferencesPayload

Autogenerated return type of UpdateBoardEpicUserPreferences.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `epicUserPreferences` | BoardEpicUserPreferences | User preferences for the epic in the board after mutation |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### UpdateBoardListPayload

Autogenerated return type of UpdateBoardList.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `list` | BoardList | Mutated list. |

### UpdateBoardPayload

Autogenerated return type of UpdateBoard.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `board` | Board | The board after mutation. |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### UpdateComplianceFrameworkPayload

Autogenerated return type of UpdateComplianceFramework.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `complianceFramework` | ComplianceFramework | The compliance framework after mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### UpdateContainerExpirationPolicyPayload

Autogenerated return type of UpdateContainerExpirationPolicy.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `containerExpirationPolicy` | ContainerExpirationPolicy | The container expiration policy after mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### UpdateDevopsAdoptionSegmentPayload

Autogenerated return type of UpdateDevopsAdoptionSegment.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `segment` | DevopsAdoptionSegment | The segment after mutation |

### UpdateEpicPayload

Autogenerated return type of UpdateEpic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `epic` | Epic | The epic after mutation |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### UpdateImageDiffNotePayload

Autogenerated return type of UpdateImageDiffNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `note` | Note | The note after mutation. |

### UpdateIssuePayload

Autogenerated return type of UpdateIssue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `issue` | Issue | The issue after mutation. |

### UpdateIterationPayload

Autogenerated return type of UpdateIteration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `iteration` | Iteration | Updated iteration. |

### UpdateNamespacePackageSettingsPayload

Autogenerated return type of UpdateNamespacePackageSettings.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `packageSettings` | PackageSettings | The namespace package setting after mutation. |

### UpdateNotePayload

Autogenerated return type of UpdateNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `note` | Note | The note after mutation. |

### UpdateRequirementPayload

Autogenerated return type of UpdateRequirement.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `requirement` | Requirement | Requirement after mutation |

### UpdateSnippetPayload

Autogenerated return type of UpdateSnippet.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `snippet` | Snippet | The snippet after mutation. |
| `spam` | Boolean | Indicates whether the operation returns a record detected as spam. |

### User

| Field | Type | Description |
| ----- | ---- | ----------- |
| `assignedMergeRequests` | MergeRequestConnection | Merge Requests assigned to the user |
| `authoredMergeRequests` | MergeRequestConnection | Merge Requests authored by the user |
| `avatarUrl` | String | URL of the user's avatar |
| `email` **{warning-solid}** | String | **Deprecated:** Use public_email. Deprecated in 13.7. |
| `groupCount` | Int | Group count for the user Available only when feature flag `user_group_counts` is enabled. |
| `groupMemberships` | GroupMemberConnection | Group memberships of the user |
| `id` | ID! | ID of the user |
| `location` | String | The location of the user. |
| `name` | String! | Human-readable name of the user |
| `projectMemberships` | ProjectMemberConnection | Project memberships of the user |
| `publicEmail` | String | User's public email |
| `reviewRequestedMergeRequests` | MergeRequestConnection | Merge Requests assigned to the user for review |
| `snippets` | SnippetConnection | Snippets authored by the user |
| `starredProjects` | ProjectConnection | Projects starred by the user |
| `state` | UserState! | State of the user |
| `status` | UserStatus | User status |
| `todos` | TodoConnection! | Todos of the user |
| `userPermissions` | UserPermissions! | Permissions for the current user on the resource |
| `username` | String! | Username of the user. Unique within this instance of GitLab |
| `webPath` | String! | Web path of the user |
| `webUrl` | String! | Web URL of the user |

### UserPermissions

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createSnippet` | Boolean! | Indicates the user can perform `create_snippet` on this resource |

### UserStatus

| Field | Type | Description |
| ----- | ---- | ----------- |
| `availability` | AvailabilityEnum! | User availability status |
| `emoji` | String | String representation of emoji |
| `message` | String | User status message |
| `messageHtml` | String | HTML of the user status message |

### VulnerabilitiesCountByDay

Represents the count of vulnerabilities by severity on a particular day. This data is retained for 365 days.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `critical` | Int! | Total number of vulnerabilities on a particular day with critical severity |
| `date` | ISO8601Date! | Date for the count |
| `high` | Int! | Total number of vulnerabilities on a particular day with high severity |
| `info` | Int! | Total number of vulnerabilities on a particular day with info severity |
| `low` | Int! | Total number of vulnerabilities on a particular day with low severity |
| `medium` | Int! | Total number of vulnerabilities on a particular day with medium severity |
| `total` | Int! | Total number of vulnerabilities on a particular day |
| `unknown` | Int! | Total number of vulnerabilities on a particular day with unknown severity |

### VulnerabilitiesCountByDayAndSeverity

Represents the number of vulnerabilities for a particular severity on a particular day. This data is retained for 365 days.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | Int | Number of vulnerabilities |
| `day` | ISO8601Date | Date for the count |
| `severity` | VulnerabilitySeverity | Severity of the counted vulnerabilities |

### Vulnerability

Represents a vulnerability.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `confirmedAt` | Time | Timestamp of when the vulnerability state was changed to confirmed |
| `confirmedBy` | User | The user that confirmed the vulnerability. |
| `description` | String | Description of the vulnerability |
| `detectedAt` | Time! | Timestamp of when the vulnerability was first detected |
| `discussions` | DiscussionConnection! | All discussions on this noteable |
| `dismissedAt` | Time | Timestamp of when the vulnerability state was changed to dismissed |
| `dismissedBy` | User | The user that dismissed the vulnerability. |
| `externalIssueLinks` | VulnerabilityExternalIssueLinkConnection! | List of external issue links related to the vulnerability |
| `hasSolutions` | Boolean | Indicates whether there is a solution available for this vulnerability. |
| `id` | ID! | GraphQL ID of the vulnerability |
| `identifiers` | VulnerabilityIdentifier! => Array | Identifiers of the vulnerability. |
| `issueLinks` | VulnerabilityIssueLinkConnection! | List of issue links related to the vulnerability |
| `location` | VulnerabilityLocation | Location metadata for the vulnerability. Its fields depend on the type of security scan that found the vulnerability |
| `mergeRequest` | MergeRequest | Merge request that fixes the vulnerability. |
| `notes` | NoteConnection! | All notes on this noteable |
| `primaryIdentifier` | VulnerabilityIdentifier | Primary identifier of the vulnerability. |
| `project` | Project | The project on which the vulnerability was found |
| `reportType` | VulnerabilityReportType | Type of the security report that found the vulnerability (SAST, DEPENDENCY_SCANNING, CONTAINER_SCANNING, DAST, SECRET_DETECTION, COVERAGE_FUZZING, API_FUZZING) |
| `resolvedAt` | Time | Timestamp of when the vulnerability state was changed to resolved |
| `resolvedBy` | User | The user that resolved the vulnerability. |
| `resolvedOnDefaultBranch` | Boolean! | Indicates whether the vulnerability is fixed on the default branch or not |
| `scanner` | VulnerabilityScanner | Scanner metadata for the vulnerability. |
| `severity` | VulnerabilitySeverity | Severity of the vulnerability (INFO, UNKNOWN, LOW, MEDIUM, HIGH, CRITICAL) |
| `state` | VulnerabilityState | State of the vulnerability (DETECTED, CONFIRMED, RESOLVED, DISMISSED) |
| `title` | String | Title of the vulnerability |
| `userNotesCount` | Int! | Number of user notes attached to the vulnerability |
| `userPermissions` | VulnerabilityPermissions! | Permissions for the current user on the resource |
| `vulnerabilityPath` | String | URL to the vulnerability's details page |

### VulnerabilityConfirmPayload

Autogenerated return type of VulnerabilityConfirm.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `vulnerability` | Vulnerability | The vulnerability after state change |

### VulnerabilityDismissPayload

Autogenerated return type of VulnerabilityDismiss.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `vulnerability` | Vulnerability | The vulnerability after dismissal |

### VulnerabilityExternalIssueLink

Represents an external issue link of a vulnerability.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `externalIssue` | ExternalIssue | The external issue attached to the issue link |
| `id` | VulnerabilitiesExternalIssueLinkID! | GraphQL ID of the external issue link |
| `linkType` | VulnerabilityExternalIssueLinkType! | Type of the external issue link |

### VulnerabilityExternalIssueLinkCreatePayload

Autogenerated return type of VulnerabilityExternalIssueLinkCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `externalIssueLink` | VulnerabilityExternalIssueLink | The created external issue link. |

### VulnerabilityExternalIssueLinkDestroyPayload

Autogenerated return type of VulnerabilityExternalIssueLinkDestroy.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |

### VulnerabilityIdentifier

Represents a vulnerability identifier.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `externalId` | String | External ID of the vulnerability identifier |
| `externalType` | String | External type of the vulnerability identifier |
| `name` | String | Name of the vulnerability identifier |
| `url` | String | URL of the vulnerability identifier |

### VulnerabilityIssueLink

Represents an issue link of a vulnerability.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `id` | ID! | GraphQL ID of the vulnerability |
| `issue` | Issue! | The issue attached to issue link |
| `linkType` | VulnerabilityIssueLinkType! | Type of the issue link |

### VulnerabilityLocationContainerScanning

Represents the location of a vulnerability found by a container security scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `dependency` | VulnerableDependency | Dependency containing the vulnerability |
| `image` | String | Name of the vulnerable container image |
| `operatingSystem` | String | Operating system that runs on the vulnerable container image |

### VulnerabilityLocationCoverageFuzzing

Represents the location of a vulnerability found by a Coverage Fuzzing scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `endLine` | String | Number of the last relevant line in the vulnerable file |
| `file` | String | Path to the vulnerable file |
| `startLine` | String | Number of the first relevant line in the vulnerable file |
| `vulnerableClass` | String | Class containing the vulnerability |
| `vulnerableMethod` | String | Method containing the vulnerability |

### VulnerabilityLocationDast

Represents the location of a vulnerability found by a DAST scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `hostname` | String | Domain name of the vulnerable request |
| `param` | String | Query parameter for the URL on which the vulnerability occurred |
| `path` | String | URL path and query string of the vulnerable request |
| `requestMethod` | String | HTTP method of the vulnerable request |

### VulnerabilityLocationDependencyScanning

Represents the location of a vulnerability found by a dependency security scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `dependency` | VulnerableDependency | Dependency containing the vulnerability |
| `file` | String | Path to the vulnerable file |

### VulnerabilityLocationSast

Represents the location of a vulnerability found by a SAST scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `endLine` | String | Number of the last relevant line in the vulnerable file |
| `file` | String | Path to the vulnerable file |
| `startLine` | String | Number of the first relevant line in the vulnerable file |
| `vulnerableClass` | String | Class containing the vulnerability |
| `vulnerableMethod` | String | Method containing the vulnerability |

### VulnerabilityLocationSecretDetection

Represents the location of a vulnerability found by a secret detection scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `endLine` | String | Number of the last relevant line in the vulnerable file |
| `file` | String | Path to the vulnerable file |
| `startLine` | String | Number of the first relevant line in the vulnerable file |
| `vulnerableClass` | String | Class containing the vulnerability |
| `vulnerableMethod` | String | Method containing the vulnerability |

### VulnerabilityPermissions

Check permissions for the current user on a vulnerability.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminVulnerability` | Boolean! | Indicates the user can perform `admin_vulnerability` on this resource |
| `adminVulnerabilityExternalIssueLink` | Boolean! | Indicates the user can perform `admin_vulnerability_external_issue_link` on this resource |
| `adminVulnerabilityIssueLink` | Boolean! | Indicates the user can perform `admin_vulnerability_issue_link` on this resource |
| `createVulnerability` | Boolean! | Indicates the user can perform `create_vulnerability` on this resource |
| `createVulnerabilityExport` | Boolean! | Indicates the user can perform `create_vulnerability_export` on this resource |
| `createVulnerabilityFeedback` | Boolean! | Indicates the user can perform `create_vulnerability_feedback` on this resource |
| `destroyVulnerabilityFeedback` | Boolean! | Indicates the user can perform `destroy_vulnerability_feedback` on this resource |
| `readVulnerabilityFeedback` | Boolean! | Indicates the user can perform `read_vulnerability_feedback` on this resource |
| `updateVulnerabilityFeedback` | Boolean! | Indicates the user can perform `update_vulnerability_feedback` on this resource |

### VulnerabilityResolvePayload

Autogenerated return type of VulnerabilityResolve.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `vulnerability` | Vulnerability | The vulnerability after state change |

### VulnerabilityRevertToDetectedPayload

Autogenerated return type of VulnerabilityRevertToDetected.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | String | A unique identifier for the client performing the mutation. |
| `errors` | String! => Array | Errors encountered during execution of the mutation. |
| `vulnerability` | Vulnerability | The vulnerability after revert |

### VulnerabilityScanner

Represents a vulnerability scanner.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `externalId` | String | External ID of the vulnerability scanner |
| `name` | String | Name of the vulnerability scanner |
| `reportType` | VulnerabilityReportType | Type of the vulnerability report |
| `vendor` | String | Vendor of the vulnerability scanner |

### VulnerabilitySeveritiesCount

Represents vulnerability counts by severity.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `critical` | Int | Number of vulnerabilities of CRITICAL severity of the project |
| `high` | Int | Number of vulnerabilities of HIGH severity of the project |
| `info` | Int | Number of vulnerabilities of INFO severity of the project |
| `low` | Int | Number of vulnerabilities of LOW severity of the project |
| `medium` | Int | Number of vulnerabilities of MEDIUM severity of the project |
| `unknown` | Int | Number of vulnerabilities of UNKNOWN severity of the project |

### VulnerableDependency

Represents a vulnerable dependency. Used in vulnerability location data.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `package` | VulnerablePackage | The package associated with the vulnerable dependency |
| `version` | String | The version of the vulnerable dependency |

### VulnerablePackage

Represents a vulnerable package. Used in vulnerability dependency data.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `name` | String | The name of the vulnerable package |

### VulnerableProjectsByGrade

Represents vulnerability letter grades with associated projects.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | Int! | Number of projects within this grade |
| `grade` | VulnerabilityGrade! | Grade based on the highest severity vulnerability present |
| `projects` | ProjectConnection! | Projects within this grade |

## Enumeration types

Also called _Enums_, enumeration types are a special kind of scalar that
is restricted to a particular set of allowed values.

For more information, see
[Enumeration Types](https://graphql.org/learn/schema/#enumeration-types)
on `graphql.org`.

### AccessLevelEnum

Access level to a resource.

| Value | Description |
| ----- | ----------- |
| `DEVELOPER` |  |
| `GUEST` |  |
| `MAINTAINER` |  |
| `NO_ACCESS` |  |
| `OWNER` |  |
| `REPORTER` |  |

### AlertManagementAlertSort

Values for sorting alerts.

| Value | Description |
| ----- | ----------- |
| `CREATED_ASC` | Created at ascending order |
| `CREATED_DESC` | Created at descending order |
| `CREATED_TIME_ASC` | Created time by ascending order |
| `CREATED_TIME_DESC` | Created time by descending order |
| `ENDED_AT_ASC` | End time by ascending order |
| `ENDED_AT_DESC` | End time by descending order |
| `EVENT_COUNT_ASC` | Events count by ascending order |
| `EVENT_COUNT_DESC` | Events count by descending order |
| `SEVERITY_ASC` | Severity from less critical to more critical |
| `SEVERITY_DESC` | Severity from more critical to less critical |
| `STARTED_AT_ASC` | Start time by ascending order |
| `STARTED_AT_DESC` | Start time by descending order |
| `STATUS_ASC` | Status by order: Ignored > Resolved > Acknowledged > Triggered |
| `STATUS_DESC` | Status by order: Triggered > Acknowledged > Resolved > Ignored |
| `UPDATED_ASC` | Updated at ascending order |
| `UPDATED_DESC` | Updated at descending order |
| `UPDATED_TIME_ASC` | Created time by ascending order |
| `UPDATED_TIME_DESC` | Created time by descending order |
| `created_asc` **{warning-solid}** | **Deprecated:** Use CREATED_ASC. Deprecated in 13.5. |
| `created_desc` **{warning-solid}** | **Deprecated:** Use CREATED_DESC. Deprecated in 13.5. |
| `updated_asc` **{warning-solid}** | **Deprecated:** Use UPDATED_ASC. Deprecated in 13.5. |
| `updated_desc` **{warning-solid}** | **Deprecated:** Use UPDATED_DESC. Deprecated in 13.5. |

### AlertManagementDomainFilter

Filters the alerts based on given domain.

| Value | Description |
| ----- | ----------- |
| `operations` | Alerts for operations domain  |
| `threat_monitoring` | Alerts for threat monitoring domain |

### AlertManagementIntegrationType

Values of types of integrations.

| Value | Description |
| ----- | ----------- |
| `HTTP` | Integration with any monitoring tool |
| `PROMETHEUS` | Prometheus integration |

### AlertManagementSeverity

Alert severity values.

| Value | Description |
| ----- | ----------- |
| `CRITICAL` | Critical severity |
| `HIGH` | High severity |
| `INFO` | Info severity |
| `LOW` | Low severity |
| `MEDIUM` | Medium severity |
| `UNKNOWN` | Unknown severity |

### AlertManagementStatus

Alert status values.

| Value | Description |
| ----- | ----------- |
| `ACKNOWLEDGED` | Acknowledged status |
| `IGNORED` | Ignored status |
| `RESOLVED` | Resolved status |
| `TRIGGERED` | Triggered status |

### AvailabilityEnum

User availability status.

| Value | Description |
| ----- | ----------- |
| `BUSY` | Busy |
| `NOT_SET` | Not Set |

### BlobViewersType

Types of blob viewers.

| Value | Description |
| ----- | ----------- |
| `auxiliary` |  |
| `rich` |  |
| `simple` |  |

### CiConfigStatus

Values for YAML processor result.

| Value | Description |
| ----- | ----------- |
| `INVALID` | The configuration file is not valid |
| `VALID` | The configuration file is valid |

### CommitActionMode

Mode of a commit action.

| Value | Description |
| ----- | ----------- |
| `CHMOD` | Chmod command |
| `CREATE` | Create command |
| `DELETE` | Delete command |
| `MOVE` | Move command |
| `UPDATE` | Update command |

### CommitEncoding

| Value | Description |
| ----- | ----------- |
| `BASE64` | Base64 encoding |
| `TEXT` | Text encoding |

### ContainerExpirationPolicyCadenceEnum

| Value | Description |
| ----- | ----------- |
| `EVERY_DAY` | Every day |
| `EVERY_MONTH` | Every month |
| `EVERY_THREE_MONTHS` | Every three months |
| `EVERY_TWO_WEEKS` | Every two weeks |
| `EVERY_WEEK` | Every week |

### ContainerExpirationPolicyKeepEnum

| Value | Description |
| ----- | ----------- |
| `FIFTY_TAGS` | 50 tags per image name |
| `FIVE_TAGS` | 5 tags per image name |
| `ONE_HUNDRED_TAGS` | 100 tags per image name |
| `ONE_TAG` | 1 tag per image name |
| `TEN_TAGS` | 10 tags per image name |
| `TWENTY_FIVE_TAGS` | 25 tags per image name |

### ContainerExpirationPolicyOlderThanEnum

| Value | Description |
| ----- | ----------- |
| `FOURTEEN_DAYS` | 14 days until tags are automatically removed |
| `NINETY_DAYS` | 90 days until tags are automatically removed |
| `SEVEN_DAYS` | 7 days until tags are automatically removed |
| `THIRTY_DAYS` | 30 days until tags are automatically removed |

### ContainerRepositoryCleanupStatus

Status of the tags cleanup of a container repository.

| Value | Description |
| ----- | ----------- |
| `ONGOING` | The tags cleanup is ongoing. |
| `SCHEDULED` | The tags cleanup is scheduled and is going to be executed shortly. |
| `UNFINISHED` | The tags cleanup has been partially executed. There are still remaining tags to delete. |
| `UNSCHEDULED` | The tags cleanup is not scheduled. This is the default state. |

### ContainerRepositoryStatus

Status of a container repository.

| Value | Description |
| ----- | ----------- |
| `DELETE_FAILED` | Delete Failed status. |
| `DELETE_SCHEDULED` | Delete Scheduled status. |

### DastScanTypeEnum

| Value | Description |
| ----- | ----------- |
| `ACTIVE` | Active DAST scan. This scan will make active attacks against the target site. |
| `PASSIVE` | Passive DAST scan. This scan will not make active attacks against the target site. |

### DastSiteProfileValidationStatusEnum

| Value | Description |
| ----- | ----------- |
| `FAILED_VALIDATION` | Site validation process finished but failed |
| `INPROGRESS_VALIDATION` | Site validation process is in progress |
| `NONE` | No site validation exists |
| `PASSED_VALIDATION` | Site validation process finished successfully |
| `PENDING_VALIDATION` | Site validation process has not started |

### DastSiteValidationStrategyEnum

| Value | Description |
| ----- | ----------- |
| `HEADER` | Header validation |
| `TEXT_FILE` | Text file validation |

### DataVisualizationColorEnum

Color of the data visualization palette.

| Value | Description |
| ----- | ----------- |
| `AQUA` | Aqua color |
| `BLUE` | Blue color |
| `GREEN` | Green color |
| `MAGENTA` | Magenta color |
| `ORANGE` | Orange color |

### DataVisualizationWeightEnum

Weight of the data visualization palette.

| Value | Description |
| ----- | ----------- |
| `WEIGHT_100` | 100 weight |
| `WEIGHT_200` | 200 weight |
| `WEIGHT_300` | 300 weight |
| `WEIGHT_400` | 400 weight |
| `WEIGHT_50` | 50 weight |
| `WEIGHT_500` | 500 weight |
| `WEIGHT_600` | 600 weight |
| `WEIGHT_700` | 700 weight |
| `WEIGHT_800` | 800 weight |
| `WEIGHT_900` | 900 weight |
| `WEIGHT_950` | 950 weight |

### DesignCollectionCopyState

Copy state of a DesignCollection.

| Value | Description |
| ----- | ----------- |
| `ERROR` | The DesignCollection encountered an error during a copy |
| `IN_PROGRESS` | The DesignCollection is being copied |
| `READY` | The DesignCollection has no copy in progress |

### DesignVersionEvent

Mutation event of a design within a version.

| Value | Description |
| ----- | ----------- |
| `CREATION` | A creation event |
| `DELETION` | A deletion event |
| `MODIFICATION` | A modification event |
| `NONE` | No change |

### DiffPositionType

Type of file the position refers to.

| Value | Description |
| ----- | ----------- |
| `image` |  |
| `text` |  |

### EntryType

Type of a tree entry.

| Value | Description |
| ----- | ----------- |
| `blob` |  |
| `commit` |  |
| `tree` |  |

### EpicSort

Roadmap sort values.

| Value | Description |
| ----- | ----------- |
| `end_date_asc` | End date at ascending order |
| `end_date_desc` | End date at descending order |
| `start_date_asc` | Start date at ascending order |
| `start_date_desc` | Start date at descending order |

### EpicState

State of an epic.

| Value | Description |
| ----- | ----------- |
| `all` |  |
| `closed` |  |
| `opened` |  |

### EpicStateEvent

State event of an epic.

| Value | Description |
| ----- | ----------- |
| `CLOSE` | Close the epic |
| `REOPEN` | Reopen the epic |

### EpicWildcardId

Epic ID wildcard values.

| Value | Description |
| ----- | ----------- |
| `ANY` | Any epic is assigned |
| `NONE` | No epic is assigned |

### GroupMemberRelation

Group member relation.

| Value | Description |
| ----- | ----------- |
| `DESCENDANTS` | Descendants members |
| `DIRECT` | Direct members |
| `INHERITED` | Inherited members |

### HealthStatus

Health status of an issue or epic.

| Value | Description |
| ----- | ----------- |
| `atRisk` |  |
| `needsAttention` |  |
| `onTrack` |  |

### IssuableSeverity

Incident severity.

| Value | Description |
| ----- | ----------- |
| `CRITICAL` | Critical severity |
| `HIGH` | High severity |
| `LOW` | Low severity |
| `MEDIUM` | Medium severity |
| `UNKNOWN` | Unknown severity |

### IssuableState

State of a GitLab issue or merge request.

| Value | Description |
| ----- | ----------- |
| `all` |  |
| `closed` |  |
| `locked` |  |
| `opened` |  |

### IssueSort

Values for sorting issues.

| Value | Description |
| ----- | ----------- |
| `CREATED_ASC` | Created at ascending order |
| `CREATED_DESC` | Created at descending order |
| `DUE_DATE_ASC` | Due date by ascending order |
| `DUE_DATE_DESC` | Due date by descending order |
| `LABEL_PRIORITY_ASC` | Label priority by ascending order |
| `LABEL_PRIORITY_DESC` | Label priority by descending order |
| `MILESTONE_DUE_ASC` | Milestone due date by ascending order |
| `MILESTONE_DUE_DESC` | Milestone due date by descending order |
| `PRIORITY_ASC` | Priority by ascending order |
| `PRIORITY_DESC` | Priority by descending order |
| `PUBLISHED_ASC` | Published issues shown last |
| `PUBLISHED_DESC` | Published issues shown first |
| `RELATIVE_POSITION_ASC` | Relative position by ascending order |
| `SEVERITY_ASC` | Severity from less critical to more critical |
| `SEVERITY_DESC` | Severity from more critical to less critical |
| `SLA_DUE_AT_ASC` | Issues with earliest SLA due time shown first |
| `SLA_DUE_AT_DESC` | Issues with latest SLA due time shown first |
| `UPDATED_ASC` | Updated at ascending order |
| `UPDATED_DESC` | Updated at descending order |
| `WEIGHT_ASC` | Weight by ascending order |
| `WEIGHT_DESC` | Weight by descending order |
| `created_asc` **{warning-solid}** | **Deprecated:** Use CREATED_ASC. Deprecated in 13.5. |
| `created_desc` **{warning-solid}** | **Deprecated:** Use CREATED_DESC. Deprecated in 13.5. |
| `updated_asc` **{warning-solid}** | **Deprecated:** Use UPDATED_ASC. Deprecated in 13.5. |
| `updated_desc` **{warning-solid}** | **Deprecated:** Use UPDATED_DESC. Deprecated in 13.5. |

### IssueState

State of a GitLab issue.

| Value | Description |
| ----- | ----------- |
| `all` |  |
| `closed` |  |
| `locked` |  |
| `opened` |  |

### IssueStateEvent

Values for issue state events.

| Value | Description |
| ----- | ----------- |
| `CLOSE` | Closes the issue |
| `REOPEN` | Reopens the issue |

### IssueType

Issue type.

| Value | Description |
| ----- | ----------- |
| `INCIDENT` | Incident issue type |
| `ISSUE` | Issue issue type |
| `TEST_CASE` | Test Case issue type |

### IterationState

State of a GitLab iteration.

| Value | Description |
| ----- | ----------- |
| `all` |  |
| `closed` |  |
| `opened` |  |
| `started` |  |
| `upcoming` |  |

### IterationWildcardId

Iteration ID wildcard values.

| Value | Description |
| ----- | ----------- |
| `ANY` | An iteration is assigned |
| `CURRENT` | Current iteration |
| `NONE` | No iteration is assigned |

### JobArtifactFileType

| Value | Description |
| ----- | ----------- |
| `ACCESSIBILITY` |  |
| `API_FUZZING` |  |
| `ARCHIVE` |  |
| `BROWSER_PERFORMANCE` |  |
| `CLUSTER_APPLICATIONS` |  |
| `COBERTURA` |  |
| `CODEQUALITY` |  |
| `CONTAINER_SCANNING` |  |
| `COVERAGE_FUZZING` |  |
| `DAST` |  |
| `DEPENDENCY_SCANNING` |  |
| `DOTENV` |  |
| `JUNIT` |  |
| `LICENSE_MANAGEMENT` |  |
| `LICENSE_SCANNING` |  |
| `LOAD_PERFORMANCE` |  |
| `LSIF` |  |
| `METADATA` |  |
| `METRICS` |  |
| `METRICS_REFEREE` |  |
| `NETWORK_REFEREE` |  |
| `PERFORMANCE` |  |
| `REQUIREMENTS` |  |
| `SAST` |  |
| `SECRET_DETECTION` |  |
| `TERRAFORM` |  |
| `TRACE` |  |

### ListLimitMetric

List limit metric setting.

| Value | Description |
| ----- | ----------- |
| `all_metrics` |  |
| `issue_count` |  |
| `issue_weights` |  |

### MeasurementIdentifier

Possible identifier types for a measurement.

| Value | Description |
| ----- | ----------- |
| `GROUPS` | Group count |
| `ISSUES` | Issue count |
| `MERGE_REQUESTS` | Merge request count |
| `PIPELINES` | Pipeline count |
| `PIPELINES_CANCELED` | Pipeline count with canceled status |
| `PIPELINES_FAILED` | Pipeline count with failed status |
| `PIPELINES_SKIPPED` | Pipeline count with skipped status |
| `PIPELINES_SUCCEEDED` | Pipeline count with success status |
| `PROJECTS` | Project count |
| `USERS` | User count |

### MergeRequestSort

Values for sorting merge requests.

| Value | Description |
| ----- | ----------- |
| `CREATED_ASC` | Created at ascending order |
| `CREATED_DESC` | Created at descending order |
| `LABEL_PRIORITY_ASC` | Label priority by ascending order |
| `LABEL_PRIORITY_DESC` | Label priority by descending order |
| `MERGED_AT_ASC` | Merge time by ascending order |
| `MERGED_AT_DESC` | Merge time by descending order |
| `MILESTONE_DUE_ASC` | Milestone due date by ascending order |
| `MILESTONE_DUE_DESC` | Milestone due date by descending order |
| `PRIORITY_ASC` | Priority by ascending order |
| `PRIORITY_DESC` | Priority by descending order |
| `UPDATED_ASC` | Updated at ascending order |
| `UPDATED_DESC` | Updated at descending order |
| `created_asc` **{warning-solid}** | **Deprecated:** Use CREATED_ASC. Deprecated in 13.5. |
| `created_desc` **{warning-solid}** | **Deprecated:** Use CREATED_DESC. Deprecated in 13.5. |
| `updated_asc` **{warning-solid}** | **Deprecated:** Use UPDATED_ASC. Deprecated in 13.5. |
| `updated_desc` **{warning-solid}** | **Deprecated:** Use UPDATED_DESC. Deprecated in 13.5. |

### MergeRequestState

State of a GitLab merge request.

| Value | Description |
| ----- | ----------- |
| `all` |  |
| `closed` |  |
| `locked` |  |
| `merged` |  |
| `opened` |  |

### MilestoneStateEnum

| Value | Description |
| ----- | ----------- |
| `active` |  |
| `closed` |  |

### MoveType

The position to which the adjacent object should be moved.

| Value | Description |
| ----- | ----------- |
| `after` | The adjacent object will be moved after the object that is being moved |
| `before` | The adjacent object will be moved before the object that is being moved |

### MutationOperationMode

Different toggles for changing mutator behavior.

| Value | Description |
| ----- | ----------- |
| `APPEND` | Performs an append operation |
| `REMOVE` | Performs a removal operation |
| `REPLACE` | Performs a replace operation |

### NamespaceProjectSort

Values for sorting projects.

| Value | Description |
| ----- | ----------- |
| `SIMILARITY` | Most similar to the search query |
| `STORAGE` | Sort by storage size |

### OncallRotationUnitEnum

Rotation length unit of an on-call rotation.

| Value | Description |
| ----- | ----------- |
| `DAYS` | Days |
| `HOURS` | Hours |
| `WEEKS` | Weeks |

### PackageTypeEnum

| Value | Description |
| ----- | ----------- |
| `COMPOSER` | Packages from the Composer package manager |
| `CONAN` | Packages from the Conan package manager |
| `DEBIAN` | Packages from the Debian package manager |
| `GENERIC` | Packages from the Generic package manager |
| `GOLANG` | Packages from the Golang package manager |
| `MAVEN` | Packages from the Maven package manager |
| `NPM` | Packages from the NPM package manager |
| `NUGET` | Packages from the Nuget package manager |
| `PYPI` | Packages from the PyPI package manager |

### PipelineConfigSourceEnum

| Value | Description |
| ----- | ----------- |
| `AUTO_DEVOPS_SOURCE` |  |
| `BRIDGE_SOURCE` |  |
| `EXTERNAL_PROJECT_SOURCE` |  |
| `PARAMETER_SOURCE` |  |
| `REMOTE_SOURCE` |  |
| `REPOSITORY_SOURCE` |  |
| `UNKNOWN_SOURCE` |  |
| `WEBIDE_SOURCE` |  |

### PipelineStatusEnum

| Value | Description |
| ----- | ----------- |
| `CANCELED` |  |
| `CREATED` |  |
| `FAILED` |  |
| `MANUAL` |  |
| `PENDING` |  |
| `PREPARING` |  |
| `RUNNING` |  |
| `SCHEDULED` |  |
| `SKIPPED` |  |
| `SUCCESS` |  |
| `WAITING_FOR_RESOURCE` |  |

### ProjectMemberRelation

Project member relation.

| Value | Description |
| ----- | ----------- |
| `DESCENDANTS` | Descendants members |
| `DIRECT` | Direct members |
| `INHERITED` | Inherited members |
| `INVITED_GROUPS` | Invited Groups members |

### RegistryState

State of a Geo registry.

| Value | Description |
| ----- | ----------- |
| `FAILED` | Registry that failed to sync |
| `PENDING` | Registry waiting to be synced |
| `STARTED` | Registry currently syncing |
| `SYNCED` | Registry that is synced |

### ReleaseAssetLinkType

Type of the link: `other`, `runbook`, `image`, `package`.

| Value | Description |
| ----- | ----------- |
| `IMAGE` | Image link type |
| `OTHER` | Other link type |
| `PACKAGE` | Package link type |
| `RUNBOOK` | Runbook link type |

### ReleaseSort

Values for sorting releases.

| Value | Description |
| ----- | ----------- |
| `CREATED_ASC` | Created at ascending order |
| `CREATED_DESC` | Created at descending order |
| `RELEASED_AT_ASC` | Released at by ascending order |
| `RELEASED_AT_DESC` | Released at by descending order |

### RequirementState

State of a requirement.

| Value | Description |
| ----- | ----------- |
| `ARCHIVED` |  |
| `OPENED` |  |

### SastUiComponentSize

Size of UI component in SAST configuration page.

| Value | Description |
| ----- | ----------- |
| `LARGE` |  |
| `MEDIUM` |  |
| `SMALL` |  |

### SecurityReportTypeEnum

| Value | Description |
| ----- | ----------- |
| `API_FUZZING` | API FUZZING scan report |
| `CONTAINER_SCANNING` | CONTAINER SCANNING scan report |
| `COVERAGE_FUZZING` | COVERAGE FUZZING scan report |
| `DAST` | DAST scan report |
| `DEPENDENCY_SCANNING` | DEPENDENCY SCANNING scan report |
| `SAST` | SAST scan report |
| `SECRET_DETECTION` | SECRET DETECTION scan report |

### SecurityScannerType

The type of the security scanner.

| Value | Description |
| ----- | ----------- |
| `API_FUZZING` |  |
| `CONTAINER_SCANNING` |  |
| `COVERAGE_FUZZING` |  |
| `DAST` |  |
| `DEPENDENCY_SCANNING` |  |
| `SAST` |  |
| `SECRET_DETECTION` |  |

### SentryErrorStatus

State of a Sentry error.

| Value | Description |
| ----- | ----------- |
| `IGNORED` | Error has been ignored |
| `RESOLVED` | Error has been resolved |
| `RESOLVED_IN_NEXT_RELEASE` | Error has been ignored until next release |
| `UNRESOLVED` | Error is unresolved |

### ServiceType

| Value | Description |
| ----- | ----------- |
| `ALERTS_SERVICE` |  |
| `ASANA_SERVICE` |  |
| `ASSEMBLA_SERVICE` |  |
| `BAMBOO_SERVICE` |  |
| `BUGZILLA_SERVICE` |  |
| `BUILDKITE_SERVICE` |  |
| `CAMPFIRE_SERVICE` |  |
| `CONFLUENCE_SERVICE` |  |
| `CUSTOM_ISSUE_TRACKER_SERVICE` |  |
| `DATADOG_SERVICE` |  |
| `DISCORD_SERVICE` |  |
| `DRONE_CI_SERVICE` |  |
| `EMAILS_ON_PUSH_SERVICE` |  |
| `EWM_SERVICE` |  |
| `EXTERNAL_WIKI_SERVICE` |  |
| `FLOWDOCK_SERVICE` |  |
| `GITHUB_SERVICE` |  |
| `HANGOUTS_CHAT_SERVICE` |  |
| `HIPCHAT_SERVICE` |  |
| `IRKER_SERVICE` |  |
| `JENKINS_SERVICE` |  |
| `JIRA_SERVICE` |  |
| `MATTERMOST_SERVICE` |  |
| `MATTERMOST_SLASH_COMMANDS_SERVICE` |  |
| `MICROSOFT_TEAMS_SERVICE` |  |
| `PACKAGIST_SERVICE` |  |
| `PIPELINES_EMAIL_SERVICE` |  |
| `PIVOTALTRACKER_SERVICE` |  |
| `PROMETHEUS_SERVICE` |  |
| `PUSHOVER_SERVICE` |  |
| `REDMINE_SERVICE` |  |
| `SLACK_SERVICE` |  |
| `SLACK_SLASH_COMMANDS_SERVICE` |  |
| `TEAMCITY_SERVICE` |  |
| `UNIFY_CIRCUIT_SERVICE` |  |
| `WEBEX_TEAMS_SERVICE` |  |
| `YOUTRACK_SERVICE` |  |

### SnippetBlobActionEnum

Type of a snippet blob input action.

| Value | Description |
| ----- | ----------- |
| `create` |  |
| `delete` |  |
| `move` |  |
| `update` |  |

### Sort

Common sort values.

| Value | Description |
| ----- | ----------- |
| `CREATED_ASC` | Created at ascending order |
| `CREATED_DESC` | Created at descending order |
| `UPDATED_ASC` | Updated at ascending order |
| `UPDATED_DESC` | Updated at descending order |
| `created_asc` **{warning-solid}** | **Deprecated:** Use CREATED_ASC. Deprecated in 13.5. |
| `created_desc` **{warning-solid}** | **Deprecated:** Use CREATED_DESC. Deprecated in 13.5. |
| `updated_asc` **{warning-solid}** | **Deprecated:** Use UPDATED_ASC. Deprecated in 13.5. |
| `updated_desc` **{warning-solid}** | **Deprecated:** Use UPDATED_DESC. Deprecated in 13.5. |

### TestReportState

State of a test report.

| Value | Description |
| ----- | ----------- |
| `FAILED` |  |
| `PASSED` |  |

### TodoActionEnum

| Value | Description |
| ----- | ----------- |
| `approval_required` |  |
| `assigned` |  |
| `build_failed` |  |
| `directly_addressed` |  |
| `marked` |  |
| `mentioned` |  |
| `unmergeable` |  |

### TodoStateEnum

| Value | Description |
| ----- | ----------- |
| `done` |  |
| `pending` |  |

### TodoTargetEnum

| Value | Description |
| ----- | ----------- |
| `ALERT` | An Alert |
| `COMMIT` | A Commit |
| `DESIGN` | A Design |
| `EPIC` | An Epic |
| `ISSUE` | An Issue |
| `MERGEREQUEST` | A MergeRequest |

### TypeEnum

| Value | Description |
| ----- | ----------- |
| `personal` |  |
| `project` |  |

### UserState

Possible states of a user.

| Value | Description |
| ----- | ----------- |
| `active` | The user is active and is able to use the system |
| `blocked` | The user has been blocked and is prevented from using the system |
| `deactivated` | The user is no longer active and is unable to use the system |

### VisibilityLevelsEnum

| Value | Description |
| ----- | ----------- |
| `internal` |  |
| `private` |  |
| `public` |  |

### VisibilityScopesEnum

| Value | Description |
| ----- | ----------- |
| `internal` |  |
| `private` |  |
| `public` |  |

### VulnerabilityDismissalReason

The dismissal reason of the Vulnerability.

| Value | Description |
| ----- | ----------- |
| `ACCEPTABLE_RISK` | The likelihood of the Vulnerability occurring and its impact are deemed acceptable |
| `FALSE_POSITIVE` | The Vulnerability was incorrectly identified as being present |
| `MITIGATING_CONTROL` | There is a mitigating control that eliminates the Vulnerability or makes its risk acceptable |
| `NOT_APPLICABLE` | Other reasons for dismissal |
| `USED_IN_TESTS` | The Vulnerability is used in tests and does not pose an actual risk |

### VulnerabilityExternalIssueLinkExternalTracker

The external tracker of the external issue link related to a vulnerability.

| Value | Description |
| ----- | ----------- |
| `JIRA` | Jira external tracker |

### VulnerabilityExternalIssueLinkType

The type of the external issue link related to a vulnerability.

| Value | Description |
| ----- | ----------- |
| `CREATED` | Created link type |

### VulnerabilityGrade

The grade of the vulnerable project.

| Value | Description |
| ----- | ----------- |
| `A` |  |
| `B` |  |
| `C` |  |
| `D` |  |
| `F` |  |

### VulnerabilityIssueLinkType

The type of the issue link related to a vulnerability.

| Value | Description |
| ----- | ----------- |
| `CREATED` |  |
| `RELATED` |  |

### VulnerabilityReportType

The type of the security scan that found the vulnerability.

| Value | Description |
| ----- | ----------- |
| `API_FUZZING` |  |
| `CONTAINER_SCANNING` |  |
| `COVERAGE_FUZZING` |  |
| `DAST` |  |
| `DEPENDENCY_SCANNING` |  |
| `SAST` |  |
| `SECRET_DETECTION` |  |

### VulnerabilitySeverity

The severity of the vulnerability.

| Value | Description |
| ----- | ----------- |
| `CRITICAL` |  |
| `HIGH` |  |
| `INFO` |  |
| `LOW` |  |
| `MEDIUM` |  |
| `UNKNOWN` |  |

### VulnerabilitySort

Vulnerability sort values.

| Value | Description |
| ----- | ----------- |
| `detected_asc` | Detection timestamp in ascending order |
| `detected_desc` | Detection timestamp in descending order |
| `report_type_asc` | Report Type in ascending order |
| `report_type_desc` | Report Type in descending order |
| `severity_asc` | Severity in ascending order |
| `severity_desc` | Severity in descending order |
| `state_asc` | State in ascending order |
| `state_desc` | State in descending order |
| `title_asc` | Title in ascending order |
| `title_desc` | Title in descending order |

### VulnerabilityState

The state of the vulnerability.

| Value | Description |
| ----- | ----------- |
| `CONFIRMED` |  |
| `DETECTED` |  |
| `DISMISSED` |  |
| `RESOLVED` |  |
